@@ -9,6 +9,7 @@
 
 #include "base/allocator/allocator_shim_internals.h"
 #include "base/allocator/buildflags.h"
+#include "base/allocator/partition_allocator/allocation_guard.h"
 #include "base/allocator/partition_allocator/memory_reclaimer.h"
 #include "base/allocator/partition_allocator/partition_alloc.h"
 #include "base/allocator/partition_allocator/partition_alloc_check.h"
@@ -22,6 +23,7 @@
 #include "base/no_destructor.h"
 #include "base/numerics/checked_math.h"
 #include "build/build_config.h"
+#include "build/chromecast_buildflags.h"
 
 #if defined(OS_LINUX) || defined(OS_CHROMEOS)
 #include <malloc.h>
@@ -130,16 +132,14 @@ class MainPartitionConstructor {
   static base::ThreadSafePartitionRoot* New(void* buffer) {
     constexpr base::PartitionOptions::ThreadCache thread_cache =
 #if BUILDFLAG(USE_PARTITION_ALLOC_AS_MALLOC)
-#if BUILDFLAG(USE_BACKUP_REF_PTR)
-        // With USE_BACKUP_REF_PTR, a BRP-enabled partition may be created
-        // later. Since only one partition can have thread cache enabled, leave
-        // this ability to that partition. If BRP-enabled partition isn't
-        // needed, the thread cache will be then turned on in this one. See
-        // ConfigurePartitionBackupRefPtrSupport().
+        // Additional partitions may be created in ConfigurePartitions(). Since
+        // only one partition can have thread cache enabled, leave this ability
+        // to the new main partition. If such a partition isn't needed, the
+        // thread cache will be then turned on in this one.
+        // TODO(bartekn): Revert crrev.com/c/3240505 once
+        // PartitionAllocSimulateBRPPartitionSplit is no longer needed. The main
+        // reason is to bring back ThreadCache::kEnabled in the default case.
         base::PartitionOptions::ThreadCache::kDisabled;
-#else
-        base::PartitionOptions::ThreadCache::kEnabled;
-#endif  // BUILDFLAG(USE_BACKUP_REF_PTR)
 #else   // BUILDFLAG(USE_PARTITION_ALLOC_AS_MALLOC)
         // Other tests, such as the ThreadCache tests create a thread cache,
         // and only one is supported at a time.
@@ -152,6 +152,7 @@ class MainPartitionConstructor {
         base::PartitionOptions::Cookie::kAllowed,
         base::PartitionOptions::BackupRefPtr::kDisabled,
         base::PartitionOptions::UseConfigurablePool::kNo,
+        base::PartitionOptions::LazyCommit::kEnabled,
     });
 
     return new_root;
@@ -164,8 +165,7 @@ base::ThreadSafePartitionRoot* Allocator() {
   return g_root.Get();
 }
 
-// Original g_root_ if it was replaced by
-// ConfigurePartitionBackupRefPtrSupport().
+// Original g_root_ if it was replaced by ConfigurePartitions().
 std::atomic<base::ThreadSafePartitionRoot*> g_original_root(nullptr);
 
 class AlignedPartitionConstructor {
@@ -258,6 +258,7 @@ namespace base {
 namespace internal {
 
 void* PartitionMalloc(const AllocatorDispatch*, size_t size, void* context) {
+  ScopedDisallowAllocations guard{};
   return Allocator()->AllocFlagsNoHooks(0, MaybeAdjustSize(size),
                                         PartitionPageSize());
 }
@@ -265,6 +266,7 @@ void* PartitionMalloc(const AllocatorDispatch*, size_t size, void* context) {
 void* PartitionMallocUnchecked(const AllocatorDispatch*,
                                size_t size,
                                void* context) {
+  ScopedDisallowAllocations guard{};
   return Allocator()->AllocFlagsNoHooks(base::PartitionAllocReturnNull,
                                         MaybeAdjustSize(size),
                                         PartitionPageSize());
@@ -274,6 +276,7 @@ void* PartitionCalloc(const AllocatorDispatch*,
                       size_t n,
                       size_t size,
                       void* context) {
+  ScopedDisallowAllocations guard{};
   const size_t total = base::CheckMul(n, MaybeAdjustSize(size)).ValueOrDie();
   return Allocator()->AllocFlagsNoHooks(base::PartitionAllocZeroFill, total,
                                         PartitionPageSize());
@@ -283,6 +286,7 @@ void* PartitionMemalign(const AllocatorDispatch*,
                         size_t alignment,
                         size_t size,
                         void* context) {
+  ScopedDisallowAllocations guard{};
   return AllocateAlignedMemory(alignment, size);
 }
 
@@ -290,6 +294,7 @@ void* PartitionAlignedAlloc(const AllocatorDispatch* dispatch,
                             size_t size,
                             size_t alignment,
                             void* context) {
+  ScopedDisallowAllocations guard{};
   return AllocateAlignedMemory(alignment, size);
 }
 
@@ -305,6 +310,7 @@ void* PartitionAlignedRealloc(const AllocatorDispatch* dispatch,
                               size_t size,
                               size_t alignment,
                               void* context) {
+  ScopedDisallowAllocations guard{};
   void* new_ptr = nullptr;
   if (size > 0) {
     size = MaybeAdjustSize(size);
@@ -333,6 +339,7 @@ void* PartitionRealloc(const AllocatorDispatch*,
                        void* address,
                        size_t size,
                        void* context) {
+  ScopedDisallowAllocations guard{};
 #if defined(OS_APPLE)
   if (UNLIKELY(!base::IsManagedByPartitionAlloc(address) && address)) {
     // A memory region allocated by the system allocator is passed in this
@@ -346,7 +353,14 @@ void* PartitionRealloc(const AllocatorDispatch*,
                                    MaybeAdjustSize(size), "");
 }
 
+#if defined(OS_ANDROID) && BUILDFLAG(IS_CHROMECAST)
+extern "C" {
+void __real_free(void*);
+}  // extern "C"
+#endif
+
 void PartitionFree(const AllocatorDispatch*, void* address, void* context) {
+  ScopedDisallowAllocations guard{};
 #if defined(OS_APPLE)
   if (UNLIKELY(!base::IsManagedByPartitionAlloc(address) && address)) {
     // A memory region allocated by the system allocator is passed in this
@@ -356,6 +370,19 @@ void PartitionFree(const AllocatorDispatch*, void* address, void* context) {
   }
 #endif  // defined(OS_APPLE)
 
+  // On Chromecast, there is at least one case where a system malloc() pointer
+  // can be passed to PartitionAlloc's free(). If we don't own the pointer, pass
+  // it along. This should not have a runtime cost vs regular Android, since on
+  // Android we have a PA_CHECK() rather than the branch here.
+#if defined(OS_ANDROID) && BUILDFLAG(IS_CHROMECAST)
+  if (UNLIKELY(!base::IsManagedByPartitionAlloc(address) && address)) {
+    // A memory region allocated by the system allocator is passed in this
+    // function.  Forward the request to `free()`, which is `__real_free()`
+    // here.
+    return __real_free(address);
+  }
+#endif
+
   base::ThreadSafePartitionRoot::FreeNoHooks(address);
 }
 
@@ -426,42 +453,38 @@ void EnablePartitionAllocMemoryReclaimer() {
   }
 }
 
-void ReconfigurePartitionAllocLazyCommit() {
+void ReconfigurePartitionAllocLazyCommit(bool enabled) {
   // Unlike other partitions, Allocator() and AlignedAllocator() do not
   // configure lazy commit upfront, because it uses base::Feature, which in turn
   // allocates memory. Thus, lazy commit configuration has to be done after
   // base::FeatureList is initialized.
   // TODO(bartekn): Aligned allocator can use the regular initialization path.
-  Allocator()->ConfigureLazyCommit();
+  Allocator()->ConfigureLazyCommit(enabled);
   auto* original_root = OriginalAllocator();
   if (original_root)
-    original_root->ConfigureLazyCommit();
-  AlignedAllocator()->ConfigureLazyCommit();
+    original_root->ConfigureLazyCommit(enabled);
+  AlignedAllocator()->ConfigureLazyCommit(enabled);
 }
 
-#if BUILDFLAG(USE_BACKUP_REF_PTR)
 alignas(base::ThreadSafePartitionRoot) uint8_t
-    g_allocator_buffer_for_ref_count_config[sizeof(
+    g_allocator_buffer_for_new_main_partition[sizeof(
         base::ThreadSafePartitionRoot)];
 
-#if BUILDFLAG(USE_DEDICATED_PARTITION_FOR_ALIGNED_ALLOC_UPON_ENABLING_BRP)
 alignas(base::ThreadSafePartitionRoot) uint8_t
     g_allocator_buffer_for_aligned_alloc_partition[sizeof(
         base::ThreadSafePartitionRoot)];
-#endif
 
-void ConfigurePartitionBackupRefPtrSupport(bool enable_brp) {
+void ConfigurePartitions(EnableBrp enable_brp,
+                         ForceSplitPartitions force_split_partitions) {
   auto* current_root = g_root.Get();
   // Call Get() to ensure g_aligned_root gets initialized. In some cases it is
   // initialized with g_root, and we want to make sure it is the pre-swap
   // value (unless explicitly overwritten below).
   auto* current_aligned_root = g_aligned_root.Get();
 
-  // When enable_brp is false, simply enable thread
-  // cache in the existing root instead of creating a new one -- the only
-  // difference between the current and new partition is the thread cache
-  // setting.
-  if (!enable_brp) {
+  // When there is no need to split partition, simply enable thread cache in the
+  // existing root.
+  if (!enable_brp && !force_split_partitions) {
     PA_DCHECK(!current_root->with_thread_cache);
     current_root->EnableThreadCacheIfSupported();
     return;
@@ -470,18 +493,26 @@ void ConfigurePartitionBackupRefPtrSupport(bool enable_brp) {
   current_root->PurgeMemory(PartitionPurgeDecommitEmptySlotSpans |
                             PartitionPurgeDiscardUnusedSystemPages);
 
-  const bool allow_aligned_alloc_in_main_root =
-#if BUILDFLAG(USE_DEDICATED_PARTITION_FOR_ALIGNED_ALLOC_UPON_ENABLING_BRP)
-      // This partition can't support AlignedAlloc. Instead, a new one is
-      // created below.
-      false;
+  // AlignedAlloc relies on natural alignment offered by the allocator (see the
+  // comment inside PartitionRoot::AlignedAllocFlags). Any extras in front of
+  // the allocation will mess up that alignment. Such extras are used when
+  // BackupRefPtr is on, in which case, we need a separate partition, dedicated
+  // to handle only aligned allocations, where those extras are disabled.
+  // However, if the "previous slot" variant is used, no dedicated partition is
+  // needed, as the extras won't interfere with the alignment requirements.
+  //
+  // Regardless of everything said above, force_split_partitions==true will
+  // force creating a dedicated partition for aligned allocations.
+  const bool use_dedicated_partition_for_aligned_alloc =
+#if BUILDFLAG(PUT_REF_COUNT_IN_PREVIOUS_SLOT)
+      force_split_partitions;
 #else
-      // No separate AlignedAlloc partition is created, so this one must
-      // support it.
       true;
 #endif
+  const bool allow_aligned_alloc_in_main_root =
+      !use_dedicated_partition_for_aligned_alloc;
 
-  auto* new_root = new (g_allocator_buffer_for_ref_count_config)
+  auto* new_root = new (g_allocator_buffer_for_new_main_partition)
       base::ThreadSafePartitionRoot({
           allow_aligned_alloc_in_main_root
               ? base::PartitionOptions::AlignedAlloc::kAllowed
@@ -489,8 +520,10 @@ void ConfigurePartitionBackupRefPtrSupport(bool enable_brp) {
           base::PartitionOptions::ThreadCache::kEnabled,
           base::PartitionOptions::Quarantine::kAllowed,
           base::PartitionOptions::Cookie::kAllowed,
-          base::PartitionOptions::BackupRefPtr::kEnabled,
+          enable_brp ? base::PartitionOptions::BackupRefPtr::kEnabled
+                     : base::PartitionOptions::BackupRefPtr::kDisabled,
           base::PartitionOptions::UseConfigurablePool::kNo,
+          base::PartitionOptions::LazyCommit::kEnabled,
       });
   g_root.Replace(new_root);
   // g_original_root has to be set after g_root, because other code doesn't
@@ -500,34 +533,29 @@ void ConfigurePartitionBackupRefPtrSupport(bool enable_brp) {
   // TODO(bartekn): Move current_root->PurgeMemory after the replacement.
   g_original_root = current_root;
 
-  base::ThreadSafePartitionRoot* new_aligned_root =
-#if BUILDFLAG(USE_DEDICATED_PARTITION_FOR_ALIGNED_ALLOC_UPON_ENABLING_BRP)
-      // If BRP is getting enabled, we need to create a new AlignedAlloc
-      // partition now.
-      // TODO(bartekn): Use the original root instead of creating a new one.
-      // It'd result in one less partition, but come at a cost of
-      // commingling types.
-      new (g_allocator_buffer_for_aligned_alloc_partition)
-          base::ThreadSafePartitionRoot({
-              base::PartitionOptions::AlignedAlloc::kAllowed,
-              base::PartitionOptions::ThreadCache::kDisabled,
-              base::PartitionOptions::Quarantine::kAllowed,
-              base::PartitionOptions::Cookie::kAllowed,
-              base::PartitionOptions::BackupRefPtr::kDisabled,
-              base::PartitionOptions::UseConfigurablePool::kNo,
-          });
-  PA_DCHECK(!allow_aligned_alloc_in_main_root);
+  base::ThreadSafePartitionRoot* new_aligned_root;
+  if (use_dedicated_partition_for_aligned_alloc) {
+    // TODO(bartekn): Use the original root instead of creating a new one. It'd
+    // result in one less partition, but come at a cost of commingling types.
+    new_aligned_root = new (g_allocator_buffer_for_aligned_alloc_partition)
+        base::ThreadSafePartitionRoot({
+            base::PartitionOptions::AlignedAlloc::kAllowed,
+            base::PartitionOptions::ThreadCache::kDisabled,
+            base::PartitionOptions::Quarantine::kAllowed,
+            base::PartitionOptions::Cookie::kAllowed,
+            base::PartitionOptions::BackupRefPtr::kDisabled,
+            base::PartitionOptions::UseConfigurablePool::kNo,
+            base::PartitionOptions::LazyCommit::kEnabled,
+        });
+  } else {
+    // The new main root can also support AlignedAlloc.
+    new_aligned_root = g_root.Get();
+  }
   PA_CHECK(current_aligned_root == g_original_root);
-#else   // USE_DEDICATED_PARTITION_FOR_ALIGNED_ALLOC_UPON_ENABLING_BRP
-      // The new main root can also support AlignedAlloc.
-      g_root.Get();
-  PA_CHECK(current_aligned_root == g_original_root);
-#endif  // USE_DEDICATED_PARTITION_FOR_ALIGNED_ALLOC_UPON_ENABLING_BRP
   g_aligned_root.Replace(new_aligned_root);
   // No need for g_original_aligned_root, because in cases where g_aligned_root
   // is replaced, it must've been g_original_root.
 }
-#endif  // BUILDFLAG(USE_BACKUP_REF_PTR)
 
 #if defined(PA_ALLOW_PCSCAN)
 void EnablePCScan(base::internal::PCScan::InitConfig config) {
