@@ -9,12 +9,12 @@
 
 #include "base/allocator/buildflags.h"
 #include "base/allocator/partition_allocator/partition_alloc-inl.h"
+#include "base/allocator/partition_allocator/partition_alloc_check.h"
 #include "base/allocator/partition_allocator/partition_alloc_config.h"
 #include "base/allocator/partition_allocator/partition_alloc_constants.h"
 #include "base/allocator/partition_allocator/partition_ref_count.h"
 #include "base/compiler_specific.h"
 #include "base/dcheck_is_on.h"
-#include "base/debug/alias.h"
 #include "base/immediate_crash.h"
 #include "base/sys_byteorder.h"
 #include "build/build_config.h"
@@ -27,20 +27,7 @@ namespace {
 #if defined(PA_HAS_FREELIST_HARDENING) || DCHECK_IS_ON()
 [[noreturn]] NOINLINE void FreelistCorruptionDetected(size_t extra) {
   // Make it visible in minidumps.
-  //
-  // To make the size stick out, surround it with two easily recognizable
-  // patterns: 0xffffffff..
-  // Locally, one can use "x/3g <%rsp address>" in GDB to see the value on
-  // x86_64.
-  size_t before = ~0;
-  base::debug::Alias(&before);
-
-  size_t tmp_extra = extra;
-  base::debug::Alias(&tmp_extra);
-
-  size_t after = ~0;
-  base::debug::Alias(&after);
-
+  PA_DEBUG_DATA_ON_STACK("extra", extra);
   IMMEDIATE_CRASH();
 }
 #endif  // defined(PA_HAS_FREELIST_HARDENING) || DCHECK_IS_ON()
