@@ -12,7 +12,6 @@
 #include "base/allocator/partition_allocator/partition_alloc_check.h"
 #include "base/allocator/partition_allocator/partition_alloc_config.h"
 #include "base/allocator/partition_allocator/partition_alloc_constants.h"
-#include "base/allocator/partition_allocator/partition_alloc_features.h"
 #include "base/allocator/partition_allocator/partition_bucket.h"
 #include "base/allocator/partition_allocator/partition_cookie.h"
 #include "base/allocator/partition_allocator/partition_oom.h"
@@ -20,8 +19,8 @@
 #include "base/allocator/partition_allocator/reservation_offset_table.h"
 #include "base/allocator/partition_allocator/starscan/pcscan.h"
 #include "base/bits.h"
-#include "base/feature_list.h"
 #include "base/memory/nonscannable_memory.h"
+#include "base/memory/tagging.h"
 #include "build/build_config.h"
 
 #if defined(OS_WIN)
@@ -229,7 +228,9 @@ static size_t PartitionPurgeSlotSpan(
   for (internal::PartitionFreelistEntry* entry = slot_span->freelist_head;
        entry;
        /**/) {
-    size_t slot_index = (reinterpret_cast<char*>(entry) - ptr) / slot_size;
+    size_t slot_index =
+        (reinterpret_cast<char*>(base::memory::UnmaskPtr(entry)) - ptr) /
+        slot_size;
     PA_DCHECK(slot_index < num_slots);
     slot_usage[slot_index] = 0;
     entry = entry->GetNext(slot_size);
@@ -456,10 +457,10 @@ void DCheckIfManagedByPartitionAllocBRPPool(void* ptr) {
 template <bool thread_safe>
 [[noreturn]] NOINLINE void PartitionRoot<thread_safe>::OutOfMemory(
     size_t size) {
-#if !defined(ARCH_CPU_64_BITS)
   const size_t virtual_address_space_size =
       total_size_of_super_pages.load(std::memory_order_relaxed) +
       total_size_of_direct_mapped_pages.load(std::memory_order_relaxed);
+#if !defined(ARCH_CPU_64_BITS)
   const size_t uncommitted_size =
       virtual_address_space_size -
       total_size_of_committed_pages.load(std::memory_order_relaxed);
@@ -481,7 +482,7 @@ template <bool thread_safe>
   // stacks, and other allocators will also consume address space).
   const size_t kReasonableVirtualSize = (is_wow_64 ? 2800 : 1024) * 1024 * 1024;
   // Make it obvious whether we are running on 64-bit Windows.
-  base::debug::Alias(&is_wow_64);
+  PA_DEBUG_DATA_ON_STACK("is_wow_64", static_cast<size_t>(is_wow_64));
 #else
   constexpr size_t kReasonableVirtualSize =
       // 1.5GiB elsewhere, since address space is typically 3GiB.
@@ -491,11 +492,21 @@ template <bool thread_safe>
     internal::PartitionOutOfMemoryWithLargeVirtualSize(
         virtual_address_space_size);
   }
+#endif  // #if !defined(ARCH_CPU_64_BITS)
 
-  // Make the virtual size visible to crash reports all the time.
-  base::debug::Alias(&virtual_address_space_size);
+  // Out of memory can be due to multiple causes, such as:
+  // - Out of GigaCage virtual address space
+  // - Out of commit due to either our process, or another one
+  // - Excessive allocations in the current process
+  //
+  // Saving these values make it easier to distinguish between these. See the
+  // documentation in PA_DEBUG_DATA_ON_STACK() on how to get these from
+  // minidumps.
+  PA_DEBUG_DATA_ON_STACK("va_size", virtual_address_space_size);
+  PA_DEBUG_DATA_ON_STACK("alloc", get_total_size_of_allocated_bytes());
+  PA_DEBUG_DATA_ON_STACK("commit", get_total_size_of_committed_pages());
+  PA_DEBUG_DATA_ON_STACK("size", size);
 
-#endif
   if (internal::g_oom_handling_function)
     (*internal::g_oom_handling_function)(size);
   OOM_CRASH(size);
@@ -503,11 +514,7 @@ template <bool thread_safe>
 
 template <bool thread_safe>
 void PartitionRoot<thread_safe>::DecommitEmptySlotSpans() {
-  for (SlotSpan*& slot_span : global_empty_slot_span_ring) {
-    if (slot_span)
-      slot_span->DecommitIfPossible(this);
-    slot_span = nullptr;
-  }
+  ShrinkEmptySlotSpansRing(0);
   // Just decommitted everything, and holding the lock, should be exactly 0.
   PA_DCHECK(empty_slot_spans_dirty_bytes == 0);
 }
@@ -515,10 +522,21 @@ void PartitionRoot<thread_safe>::DecommitEmptySlotSpans() {
 template <bool thread_safe>
 void PartitionRoot<thread_safe>::Init(PartitionOptions opts) {
   {
+#if defined(OS_APPLE)
+    // Needed to statically bound page size, which is a runtime constant on
+    // apple OSes.
+    PA_CHECK((SystemPageSize() == (size_t{1} << 12)) ||
+             (SystemPageSize() == (size_t{1} << 14)));
+#endif
+
     ScopedGuard guard{lock_};
     if (initialized)
       return;
 
+    // Swaps out the active no-op tagging intrinsics with MTE-capable ones, if
+    // running on the right hardware.
+    memory::InitializeMTESupportIfNeeded();
+
 #if defined(PA_HAS_64_BITS_POINTERS)
     // Reserve address space for partition alloc.
     internal::PartitionAddressSpace::Init();
@@ -660,16 +678,13 @@ void PartitionRoot<thread_safe>::EnableThreadCacheIfSupported() {
 }
 
 template <bool thread_safe>
-void PartitionRoot<thread_safe>::ConfigureLazyCommit() {
+void PartitionRoot<thread_safe>::ConfigureLazyCommit(bool enabled) {
 #if defined(OS_WIN)
-  bool new_value =
-      base::FeatureList::IsEnabled(features::kPartitionAllocLazyCommit);
-
   internal::ScopedGuard<thread_safe> guard{lock_};
-  if (use_lazy_commit != new_value) {
+  if (use_lazy_commit != enabled) {
     // Lazy commit can be turned off, but turning on isn't supported.
     PA_DCHECK(use_lazy_commit);
-    use_lazy_commit = new_value;
+    use_lazy_commit = enabled;
 
     for (auto* super_page_extent = first_extent; super_page_extent;
          super_page_extent = super_page_extent->next) {
@@ -905,7 +920,7 @@ void* PartitionRoot<thread_safe>::ReallocFlags(int flags,
     bool tried_in_place_for_direct_map = false;
     {
       internal::ScopedGuard<thread_safe> guard{old_root->lock_};
-      // TODO(palmer): See if we can afford to make this a CHECK.
+      // TODO(crbug.com/1257655): See if we can afford to make this a CHECK.
       PA_DCHECK(IsValidSlotSpan(slot_span));
       old_usable_size = slot_span->GetUsableSize(old_root);
 
@@ -942,7 +957,7 @@ void* PartitionRoot<thread_safe>::ReallocFlags(int flags,
   }
 
   memcpy(ret, ptr, std::min(old_usable_size, new_size));
-  Free(ptr);
+  Free(ptr);  // Implicitly protects the old ptr on MTE systems.
   return ret;
 #endif
 }
@@ -961,13 +976,43 @@ void PartitionRoot<thread_safe>::PurgeMemory(int flags) {
       DecommitEmptySlotSpans();
     if (flags & PartitionPurgeDiscardUnusedSystemPages) {
       for (Bucket& bucket : buckets) {
+        if (bucket.slot_size == kInvalidBucketSize)
+          continue;
+
         if (bucket.slot_size >= SystemPageSize())
           internal::PartitionPurgeBucket(&bucket);
+        else
+          bucket.SortSlotSpanFreelists();
       }
     }
   }
 }
 
+template <bool thread_safe>
+void PartitionRoot<thread_safe>::ShrinkEmptySlotSpansRing(size_t limit) {
+  int16_t index = global_empty_slot_span_ring_index;
+  int16_t starting_index = index;
+  while (empty_slot_spans_dirty_bytes > limit) {
+    SlotSpan* slot_span = global_empty_slot_span_ring[index];
+    // The ring is not always full, may be nullptr.
+    if (slot_span) {
+      slot_span->DecommitIfPossible(this);
+      global_empty_slot_span_ring[index] = nullptr;
+    }
+    index += 1;
+    if (index == kMaxFreeableSpans)
+      index = 0;
+
+    // Went around the whole ring, since this is locked,
+    // empty_slot_spans_dirty_bytes should be exactly 0.
+    if (index == starting_index) {
+      PA_DCHECK(empty_slot_spans_dirty_bytes == 0);
+      // Metrics issue, don't crash, return.
+      break;
+    }
+  }
+}
+
 template <bool thread_safe>
 void PartitionRoot<thread_safe>::DumpStats(const char* partition_name,
                                            bool is_light_dump,
@@ -1156,4 +1201,7 @@ static_assert(offsetof(PartitionRoot<internal::ThreadSafe>, sentinel_bucket) ==
                           sizeof(PartitionRoot<internal::ThreadSafe>::Bucket),
               "sentinel_bucket must be just after the regular buckets.");
 
+static_assert(
+    offsetof(PartitionRoot<internal::ThreadSafe>, lock_) >= 64,
+    "The lock should not be on the same cacheline as the read-mostly flags");
 }  // namespace base
