@@ -22,6 +22,8 @@
 
 namespace base {
 
+class StatsReporter;
+
 namespace internal {
 
 class PCScanTask;
@@ -105,6 +107,9 @@ class PCScanInternal final {
   void ReinitForTesting(PCScan::InitConfig);                 // IN-TEST
   void FinishScanForTesting();                               // IN-TEST
 
+  void RegisterStatsReporter(StatsReporter* reporter);
+  StatsReporter& GetReporter();
+
  private:
   friend base::NoDestructor<PCScanInternal>;
   friend class StarScanSnapshot;
@@ -137,6 +142,7 @@ class PCScanInternal final {
   const SimdSupport simd_support_;
 
   std::unique_ptr<WriteProtector> write_protector_;
+  StatsReporter* stats_reporter_;
 
   bool is_initialized_ = false;
 };
