@@ -4,9 +4,9 @@
 
 #include "base/allocator/partition_allocator/starscan/stats_collector.h"
 
+#include "base/allocator/partition_allocator/starscan/stats_reporter.h"
 #include "base/logging.h"
 #include "base/time/time.h"
-#include "base/trace_event/base_tracing.h"
 
 namespace base {
 namespace internal {
@@ -25,10 +25,10 @@ base::TimeDelta StatsCollector::GetOverallTime() const {
                                         ScannerId::kOverall);
 }
 
-void StatsCollector::ReportTracesAndHists() const {
-  ReportTracesAndHistsImpl<Context::kMutator>(mutator_trace_events_);
-  ReportTracesAndHistsImpl<Context::kScanner>(scanner_trace_events_);
-  ReportSurvivalRate();
+void StatsCollector::ReportTracesAndHists(StatsReporter& reporter) const {
+  ReportTracesAndHistsImpl<Context::kMutator>(reporter, mutator_trace_events_);
+  ReportTracesAndHistsImpl<Context::kScanner>(reporter, scanner_trace_events_);
+  ReportSurvivalRate(reporter);
 }
 
 template <Context context>
@@ -46,15 +46,13 @@ base::TimeDelta StatsCollector::GetTimeImpl(
 
 template <Context context>
 void StatsCollector::ReportTracesAndHistsImpl(
+    StatsReporter& reporter,
     const DeferredTraceEventMap<context>& event_map) const {
   std::array<base::TimeDelta, static_cast<size_t>(IdType<context>::kNumIds)>
       accumulated_events{};
   // First, report traces and accumulate each trace scope to report UMA hists.
   for (const auto& tid_and_events : event_map.get_underlying_map_unsafe()) {
     const PlatformThreadId tid = tid_and_events.first;
-    // TRACE_EVENT_* macros below drop most parameters when tracing is
-    // disabled at compile time.
-    ignore_result(tid);
     const auto& events = tid_and_events.second;
     PA_DCHECK(accumulated_events.size() == events.size());
     for (size_t id = 0; id < events.size(); ++id) {
@@ -65,13 +63,8 @@ void StatsCollector::ReportTracesAndHistsImpl(
         PA_DCHECK(event.end_time.is_null());
         continue;
       }
-      TRACE_EVENT_BEGIN(kTraceCategory,
-                        perfetto::StaticString(
-                            ToTracingString(static_cast<IdType<context>>(id))),
-                        perfetto::ThreadTrack::ForThread(tid),
-                        event.start_time);
-      TRACE_EVENT_END(kTraceCategory, perfetto::ThreadTrack::ForThread(tid),
-                      event.end_time);
+      reporter.ReportTraceEvent(static_cast<IdType<context>>(id), tid,
+                                event.start_time, event.end_time);
       accumulated_events[id] += (event.end_time - event.start_time);
     }
   }
@@ -81,21 +74,16 @@ void StatsCollector::ReportTracesAndHistsImpl(
   for (size_t id = 0; id < accumulated_events.size(); ++id) {
     if (accumulated_events[id].is_zero())
       continue;
-    UmaHistogramTimes(ToUMAString(static_cast<IdType<context>>(id)).c_str(),
-                      accumulated_events[id]);
+    reporter.ReportStats(ToUMAString(static_cast<IdType<context>>(id)).c_str(),
+                         accumulated_events[id]);
   }
 }
 
-void StatsCollector::ReportSurvivalRate() const {
+void StatsCollector::ReportSurvivalRate(StatsReporter& reporter) const {
   const double survived_rate =
       static_cast<double>(survived_quarantine_size()) / quarantine_last_size_;
-  TRACE_COUNTER1(kTraceCategory, "PCScan.SurvivedQuarantineSize",
-                 survived_quarantine_size());
-  // Multiply by 1000 since TRACE_COUNTER1 expects integer. In catapult, divide
-  // back.
-  // TODO(bikineev): Remove after switching to perfetto.
-  TRACE_COUNTER1(kTraceCategory, "PCScan.SurvivedQuarantinePercent",
-                 1000 * survived_rate);
+  reporter.ReportSurvivedQuarantineSize(survived_quarantine_size());
+  reporter.ReportSurvivedQuarantinePercent(survived_rate);
   VLOG(2) << "quarantine size: " << quarantine_last_size_ << " -> "
           << survived_quarantine_size() << ", swept bytes: " << swept_size()
           << ", survival rate: " << survived_rate;
@@ -111,8 +99,10 @@ template base::TimeDelta StatsCollector::GetTimeImpl(
     IdType<Context::kScanner>) const;
 
 template void StatsCollector::ReportTracesAndHistsImpl(
+    StatsReporter& reporter,
     const DeferredTraceEventMap<Context::kMutator>&) const;
 template void StatsCollector::ReportTracesAndHistsImpl(
+    StatsReporter& reporter,
     const DeferredTraceEventMap<Context::kScanner>&) const;
 
 }  // namespace internal
