@@ -37,6 +37,10 @@ class BASE_EXPORT ServiceProviderImpl : public ::fuchsia::sys::ServiceProvider {
 
   explicit ServiceProviderImpl(
       fidl::InterfaceHandle<::fuchsia::io::Directory> service_directory);
+
+  ServiceProviderImpl(const ServiceProviderImpl&) = delete;
+  ServiceProviderImpl& operator=(const ServiceProviderImpl&) = delete;
+
   ~ServiceProviderImpl() override;
 
   // Binds a |request| from a new client to be serviced by this ServiceProvider.
@@ -60,8 +64,6 @@ class BASE_EXPORT ServiceProviderImpl : public ::fuchsia::sys::ServiceProvider {
   const sys::ServiceDirectory directory_;
   fidl::BindingSet<::fuchsia::sys::ServiceProvider> bindings_;
   base::OnceClosure on_last_client_disconnected_;
-
-  DISALLOW_COPY_AND_ASSIGN(ServiceProviderImpl);
 };
 
 }  // namespace base
