@@ -32,7 +32,7 @@ bool HistogramNameLesser(const base::HistogramBase* a,
 }  // namespace
 
 // static
-LazyInstance<Lock>::Leaky StatisticsRecorder::lock_;
+LazyInstance<absl::Mutex>::Leaky StatisticsRecorder::lock_;
 
 // static
 StatisticsRecorder* StatisticsRecorder::top_ = nullptr;
@@ -78,14 +78,14 @@ void StatisticsRecorder::ScopedHistogramSampleObserver::RunCallback(
 }
 
 StatisticsRecorder::~StatisticsRecorder() {
-  const AutoLock auto_lock(lock_.Get());
+  const absl::MutexLock auto_lock(lock_.Pointer());
   DCHECK_EQ(this, top_);
   top_ = previous_;
 }
 
 // static
 void StatisticsRecorder::EnsureGlobalRecorderWhileLocked() {
-  lock_.Get().AssertAcquired();
+  lock_.Get().AssertHeld();
   if (top_)
     return;
 
@@ -98,7 +98,7 @@ void StatisticsRecorder::EnsureGlobalRecorderWhileLocked() {
 // static
 void StatisticsRecorder::RegisterHistogramProvider(
     const WeakPtr<HistogramProvider>& provider) {
-  const AutoLock auto_lock(lock_.Get());
+  const absl::MutexLock auto_lock(lock_.Pointer());
   EnsureGlobalRecorderWhileLocked();
   top_->providers_.push_back(provider);
 }
@@ -108,7 +108,7 @@ HistogramBase* StatisticsRecorder::RegisterOrDeleteDuplicate(
     HistogramBase* histogram) {
   // Declared before |auto_lock| to ensure correct destruction order.
   std::unique_ptr<HistogramBase> histogram_deleter;
-  const AutoLock auto_lock(lock_.Get());
+  const absl::MutexLock auto_lock(lock_.Pointer());
   EnsureGlobalRecorderWhileLocked();
 
   const char* const name = histogram->histogram_name();
@@ -144,7 +144,7 @@ const BucketRanges* StatisticsRecorder::RegisterOrDeleteDuplicateRanges(
 
   // Declared before |auto_lock| to ensure correct destruction order.
   std::unique_ptr<const BucketRanges> ranges_deleter;
-  const AutoLock auto_lock(lock_.Get());
+  const absl::MutexLock auto_lock(lock_.Pointer());
   EnsureGlobalRecorderWhileLocked();
 
   const BucketRanges* const registered = *top_->ranges_.insert(ranges).first;
@@ -190,7 +190,7 @@ std::string StatisticsRecorder::ToJSON(JSONVerbosityLevel verbosity_level) {
 // static
 std::vector<const BucketRanges*> StatisticsRecorder::GetBucketRanges() {
   std::vector<const BucketRanges*> out;
-  const AutoLock auto_lock(lock_.Get());
+  const absl::MutexLock auto_lock(lock_.Pointer());
   EnsureGlobalRecorderWhileLocked();
   out.reserve(top_->ranges_.size());
   out.assign(top_->ranges_.begin(), top_->ranges_.end());
@@ -199,22 +199,28 @@ std::vector<const BucketRanges*> StatisticsRecorder::GetBucketRanges() {
 
 // static
 HistogramBase* StatisticsRecorder::FindHistogram(base::StringPiece name) {
-  // This must be called *before* the lock is acquired below because it will
-  // call back into this object to register histograms. Those called methods
-  // will acquire the lock at that time.
+  // This must be called *before* the lock is acquired below because it may
+  // call back into StatisticsRecorder to register histograms. Those called
+  // methods will acquire the lock at that time.
   ImportGlobalPersistentHistograms();
 
-  const AutoLock auto_lock(lock_.Get());
-  EnsureGlobalRecorderWhileLocked();
-
-  const HistogramMap::const_iterator it = top_->histograms_.find(name);
-  return it != top_->histograms_.end() ? it->second : nullptr;
+  // Acquire the lock in "read" mode since we're only reading the data, not
+  // modifying anything. This allows multiple readers to look up histograms
+  // concurrently.
+  const absl::ReaderMutexLock auto_lock(lock_.Pointer());
+  if (top_) {
+    const HistogramMap::const_iterator it = top_->histograms_.find(name);
+    return it != top_->histograms_.end() ? it->second : nullptr;
+  }
+  // If we're here, |top_| was null (no StatisticsRecorder instance), so the
+  // histogram also doesn't exist.
+  return nullptr;
 }
 
 // static
 StatisticsRecorder::HistogramProviders
 StatisticsRecorder::GetHistogramProviders() {
-  const AutoLock auto_lock(lock_.Get());
+  const absl::MutexLock auto_lock(lock_.Pointer());
   EnsureGlobalRecorderWhileLocked();
   return top_->providers_;
 }
@@ -245,7 +251,7 @@ void StatisticsRecorder::PrepareDeltas(
 
 // static
 void StatisticsRecorder::InitLogOnShutdown() {
-  const AutoLock auto_lock(lock_.Get());
+  const absl::MutexLock auto_lock(lock_.Pointer());
   InitLogOnShutdownWhileLocked();
 }
 
@@ -254,7 +260,7 @@ void StatisticsRecorder::AddHistogramSampleObserver(
     const std::string& name,
     StatisticsRecorder::ScopedHistogramSampleObserver* observer) {
   DCHECK(observer);
-  const AutoLock auto_lock(lock_.Get());
+  const absl::MutexLock auto_lock(lock_.Pointer());
   EnsureGlobalRecorderWhileLocked();
 
   scoped_refptr<HistogramSampleObserverList> observers;
@@ -279,7 +285,7 @@ void StatisticsRecorder::AddHistogramSampleObserver(
 void StatisticsRecorder::RemoveHistogramSampleObserver(
     const std::string& name,
     StatisticsRecorder::ScopedHistogramSampleObserver* observer) {
-  const AutoLock auto_lock(lock_.Get());
+  const absl::MutexLock auto_lock(lock_.Pointer());
   EnsureGlobalRecorderWhileLocked();
 
   auto iter = top_->observers_.find(name);
@@ -307,7 +313,7 @@ void StatisticsRecorder::FindAndRunHistogramCallbacks(
     const char* histogram_name,
     uint64_t name_hash,
     HistogramBase::Sample sample) {
-  const AutoLock auto_lock(lock_.Get());
+  const absl::MutexLock auto_lock(lock_.Pointer());
   EnsureGlobalRecorderWhileLocked();
 
   auto it = top_->observers_.find(histogram_name);
@@ -324,7 +330,7 @@ void StatisticsRecorder::FindAndRunHistogramCallbacks(
 // static
 void StatisticsRecorder::SetGlobalSampleCallback(
     const GlobalSampleCallback& new_global_sample_callback) {
-  const AutoLock auto_lock(lock_.Get());
+  const absl::MutexLock auto_lock(lock_.Pointer());
   EnsureGlobalRecorderWhileLocked();
 
   DCHECK(!global_sample_callback() || !new_global_sample_callback);
@@ -337,14 +343,14 @@ void StatisticsRecorder::SetGlobalSampleCallback(
 
 // static
 size_t StatisticsRecorder::GetHistogramCount() {
-  const AutoLock auto_lock(lock_.Get());
+  const absl::MutexLock auto_lock(lock_.Pointer());
   EnsureGlobalRecorderWhileLocked();
   return top_->histograms_.size();
 }
 
 // static
 void StatisticsRecorder::ForgetHistogramForTesting(base::StringPiece name) {
-  const AutoLock auto_lock(lock_.Get());
+  const absl::MutexLock auto_lock(lock_.Pointer());
   EnsureGlobalRecorderWhileLocked();
 
   const HistogramMap::iterator found = top_->histograms_.find(name);
@@ -366,21 +372,21 @@ void StatisticsRecorder::ForgetHistogramForTesting(base::StringPiece name) {
 // static
 std::unique_ptr<StatisticsRecorder>
 StatisticsRecorder::CreateTemporaryForTesting() {
-  const AutoLock auto_lock(lock_.Get());
+  const absl::MutexLock auto_lock(lock_.Pointer());
   return WrapUnique(new StatisticsRecorder());
 }
 
 // static
 void StatisticsRecorder::SetRecordChecker(
     std::unique_ptr<RecordHistogramChecker> record_checker) {
-  const AutoLock auto_lock(lock_.Get());
+  const absl::MutexLock auto_lock(lock_.Pointer());
   EnsureGlobalRecorderWhileLocked();
   top_->record_checker_ = std::move(record_checker);
 }
 
 // static
 bool StatisticsRecorder::ShouldRecordHistogram(uint32_t histogram_hash) {
-  const AutoLock auto_lock(lock_.Get());
+  const absl::MutexLock auto_lock(lock_.Pointer());
   EnsureGlobalRecorderWhileLocked();
   return !top_->record_checker_ ||
          top_->record_checker_->ShouldRecord(histogram_hash);
@@ -395,7 +401,7 @@ StatisticsRecorder::Histograms StatisticsRecorder::GetHistograms() {
 
   Histograms out;
 
-  const AutoLock auto_lock(lock_.Get());
+  const absl::MutexLock auto_lock(lock_.Pointer());
   EnsureGlobalRecorderWhileLocked();
 
   out.reserve(top_->histograms_.size());
@@ -449,11 +455,8 @@ void StatisticsRecorder::ImportGlobalPersistentHistograms() {
     allocator->ImportHistogramsToStatisticsRecorder();
 }
 
-// This singleton instance should be started during the single threaded portion
-// of main(), and hence it is not thread safe. It initializes globals to provide
-// support for all future calls.
 StatisticsRecorder::StatisticsRecorder() {
-  lock_.Get().AssertAcquired();
+  lock_.Get().AssertHeld();
   previous_ = top_;
   top_ = this;
   InitLogOnShutdownWhileLocked();
@@ -461,7 +464,7 @@ StatisticsRecorder::StatisticsRecorder() {
 
 // static
 void StatisticsRecorder::InitLogOnShutdownWhileLocked() {
-  lock_.Get().AssertAcquired();
+  lock_.Get().AssertHeld();
   if (!is_vlog_initialized_ && VLOG_IS_ON(1)) {
     is_vlog_initialized_ = true;
     const auto dump_to_vlog = [](void*) {
