@@ -23,6 +23,10 @@ namespace base {
 class BASE_EXPORT ProfileBuilder {
  public:
   ProfileBuilder() = default;
+
+  ProfileBuilder(const ProfileBuilder&) = delete;
+  ProfileBuilder& operator=(const ProfileBuilder&) = delete;
+
   virtual ~ProfileBuilder() = default;
 
   // Gets the ModuleCache to be used by the StackSamplingProfiler when looking
@@ -57,9 +61,6 @@ class BASE_EXPORT ProfileBuilder {
   // |sampling_period|. Invoked when sampling a profile completes.
   virtual void OnProfileCompleted(TimeDelta profile_duration,
                                   TimeDelta sampling_period) = 0;
-
- private:
-  DISALLOW_COPY_AND_ASSIGN(ProfileBuilder);
 };
 
 }  // namespace base
