@@ -144,7 +144,8 @@ void ThreadControllerWithMessagePumpImpl::SetNextDelayedDoWork(
   // Cap at one day but remember the exact time for the above equality check on
   // the next round.
   main_thread_only().next_delayed_do_work = run_time;
-  run_time = CapAtOneDay(run_time, lazy_now);
+  if (!run_time.is_max())
+    run_time = CapAtOneDay(run_time, lazy_now);
 
   // It's very rare for PostDelayedTask to be called outside of a DoWork in
   // production, so most of the time this does nothing.
@@ -336,9 +337,9 @@ TimeTicks ThreadControllerWithMessagePumpImpl::DoWorkImpl(
         power_monitor_.IsProcessInPowerSuspendState()
             ? SequencedTaskSource::SelectTaskOption::kSkipDelayedTask
             : SequencedTaskSource::SelectTaskOption::kDefault;
-    Task* task =
+    absl::optional<SequencedTaskSource::SelectedTask> selected_task =
         main_thread_only().task_source->SelectNextTask(select_task_option);
-    if (!task)
+    if (!selected_task)
       break;
 
     // Execute the task and assume the worst: it is probably not reentrant.
@@ -350,12 +351,15 @@ TimeTicks ThreadControllerWithMessagePumpImpl::DoWorkImpl(
     // See https://crbug.com/681863 and https://crbug.com/874982
     TRACE_EVENT0(TRACE_DISABLED_BY_DEFAULT("devtools.timeline"), "RunTask");
 
-    {
-      // Trace events should finish before we call DidRunTask to ensure that
-      // SequenceManager trace events do not interfere with them.
-      TRACE_TASK_EXECUTION("ThreadControllerImpl::RunTask", *task);
-      task_annotator_.RunTask("SequenceManager RunTask", task);
-    }
+    // Note: all arguments after task are just passed to a TRACE_EVENT for
+    // logging so lambda captures are safe as lambda is executed inline.
+    task_annotator_.RunTask("ThreadControllerImpl::RunTask",
+                            selected_task->task,
+                            [&selected_task](perfetto::EventContext& ctx) {
+                              if (selected_task->task_execution_trace_logger)
+                                selected_task->task_execution_trace_logger.Run(
+                                    ctx, selected_task->task);
+                            });
 
     // This processes microtasks and is intentionally included in
     // |work_item_scope|.
@@ -378,6 +382,8 @@ TimeTicks ThreadControllerWithMessagePumpImpl::DoWorkImpl(
       power_monitor_.IsProcessInPowerSuspendState()
           ? SequencedTaskSource::SelectTaskOption::kSkipDelayedTask
           : SequencedTaskSource::SelectTaskOption::kDefault;
+  main_thread_only().task_source->RemoveAllCanceledDelayedTasksFromFront(
+      continuation_lazy_now);
   return main_thread_only().task_source->GetNextTaskTime(continuation_lazy_now,
                                                          select_task_option);
 }
