@@ -10,8 +10,8 @@
 #include "base/location.h"
 #include "base/memory/ref_counted.h"
 #include "base/pending_task.h"
-#include "base/sequenced_task_runner.h"
-#include "base/single_thread_task_runner.h"
+#include "base/task/sequenced_task_runner.h"
+#include "base/task/single_thread_task_runner.h"
 #include "base/time/time.h"
 
 namespace base {
