@@ -39,6 +39,10 @@ class HistogramTester {
 
   // Takes a snapshot of all current histograms counts.
   HistogramTester();
+
+  HistogramTester(const HistogramTester&) = delete;
+  HistogramTester& operator=(const HistogramTester&) = delete;
+
   ~HistogramTester();
 
   // We know the exact number of samples in a bucket, and that no other bucket
@@ -178,8 +182,6 @@ class HistogramTester {
   // lifecycle.
   std::map<std::string, std::unique_ptr<HistogramSamples>, std::less<>>
       histograms_snapshot_;
-
-  DISALLOW_COPY_AND_ASSIGN(HistogramTester);
 };
 
 struct Bucket {
