@@ -311,17 +311,20 @@ void PlatformThread::Detach(PlatformThreadHandle thread_handle) {
 #if !defined(OS_APPLE) && !defined(OS_FUCHSIA)
 
 // static
-bool PlatformThread::CanIncreaseThreadPriority(ThreadPriority priority) {
+bool PlatformThread::CanChangeThreadPriority(ThreadPriority from,
+                                             ThreadPriority to) {
 #if defined(OS_NACL)
   return false;
 #else
-  auto platform_specific_ability =
-      internal::CanIncreaseCurrentThreadPriorityForPlatform(priority);
-  if (platform_specific_ability)
-    return platform_specific_ability.value();
+  if (from >= to) {
+    // Decreasing thread priority on POSIX is always allowed.
+    return true;
+  }
+  if (to == ThreadPriority::REALTIME_AUDIO) {
+    return internal::CanSetThreadPriorityToRealtimeAudio();
+  }
 
-  return internal::CanLowerNiceTo(
-      internal::ThreadPriorityToNiceValue(priority));
+  return internal::CanLowerNiceTo(internal::ThreadPriorityToNiceValue(to));
 #endif  // defined(OS_NACL)
 }
 
