@@ -156,7 +156,7 @@ class BlockingMethodCaller;
 namespace system {
 class StatisticsProviderImpl;
 bool IsCoreSchedulingAvailable();
-int NumberOfProcessorsForCoreScheduling();
+int NumberOfPhysicalCores();
 }
 }
 namespace chrome_cleaner {
@@ -170,6 +170,7 @@ class BrowserProcessIOThread;
 class BrowserTestBase;
 class CategorizedWorkerPool;
 class DesktopCaptureDevice;
+class DWriteFontCollectionProxy;
 class EmergencyTraceFinalisationCoordinator;
 class InProcessUtilityThread;
 class NestedMessagePumpAndroid;
@@ -339,6 +340,12 @@ namespace webrtc {
 class DesktopConfigurationMonitor;
 }
 
+namespace base {
+class Environment;
+}
+
+bool HasWaylandDisplay(base::Environment* env);
+
 namespace base {
 
 namespace sequence_manager {
@@ -473,7 +480,8 @@ class BASE_EXPORT ScopedAllowBlocking {
   friend Profile* ::GetLastProfileMac();  // crbug.com/1176734
   friend bool PathProviderWin(int, FilePath*);
   friend bool chromeos::system::IsCoreSchedulingAvailable();
-  friend int chromeos::system::NumberOfProcessorsForCoreScheduling();
+  friend int chromeos::system::NumberOfPhysicalCores();
+  friend bool ::HasWaylandDisplay(base::Environment* env);  // crbug.com/1246928
 
   ScopedAllowBlocking(const Location& from_here = Location::Current());
   ~ScopedAllowBlocking();
@@ -545,6 +553,7 @@ class BASE_EXPORT ScopedAllowBaseSyncPrimitives {
   friend class chrome_cleaner::SystemReportComponent;
   friend class content::BrowserMainLoop;
   friend class content::BrowserProcessIOThread;
+  friend class content::DWriteFontCollectionProxy;
   friend class content::ServiceWorkerContextClient;
   friend class device::UsbContext;
   friend class functions::ExecScriptScopedAllowBaseSyncPrimitives;
