@@ -26,7 +26,7 @@
 #include "base/containers/flat_map.h"
 #include "base/containers/flat_set.h"
 #include "base/containers/linked_list.h"
-#include "base/containers/mru_cache.h"
+#include "base/containers/lru_cache.h"
 #include "base/containers/queue.h"
 #include "base/stl_util.h"
 #include "base/template_util.h"
@@ -180,8 +180,9 @@ size_t EstimateMemoryUsage(const base::flat_map<K, V, C>& map);
 template <class Key,
           class Payload,
           class HashOrComp,
-          template <typename, typename, typename> class Map>
-size_t EstimateMemoryUsage(const MRUCacheBase<Key, Payload, HashOrComp, Map>&);
+          template <typename, typename, typename>
+          class Map>
+size_t EstimateMemoryUsage(const LRUCacheBase<Key, Payload, HashOrComp, Map>&);
 
 // TODO(dskiba):
 //   std::forward_list
@@ -506,10 +507,10 @@ size_t HashMapBucketCountForTesting(size_t bucket_count) {
   return bucket_count;
 }
 
-template <class MruCacheType>
-size_t DoEstimateMemoryUsageForMruCache(const MruCacheType& mru_cache) {
-  return EstimateMemoryUsage(mru_cache.ordering_) +
-         EstimateMemoryUsage(mru_cache.index_);
+template <class LruCacheType>
+size_t DoEstimateMemoryUsageForLruCache(const LruCacheType& lru_cache) {
+  return EstimateMemoryUsage(lru_cache.ordering_) +
+         EstimateMemoryUsage(lru_cache.index_);
 }
 
 }  // namespace internal
@@ -653,10 +654,11 @@ size_t EstimateMemoryUsage(const base::flat_map<K, V, C>& map) {
 template <class Key,
           class Payload,
           class HashOrComp,
-          template <typename, typename, typename> class Map>
+          template <typename, typename, typename>
+          class Map>
 size_t EstimateMemoryUsage(
-    const MRUCacheBase<Key, Payload, HashOrComp, Map>& mru_cache) {
-  return internal::DoEstimateMemoryUsageForMruCache(mru_cache);
+    const LRUCacheBase<Key, Payload, HashOrComp, Map>& lru_cache) {
+  return internal::DoEstimateMemoryUsageForLruCache(lru_cache);
 }
 
 }  // namespace trace_event
