@@ -11,8 +11,8 @@
 #include "base/logging.h"
 #include "base/macros.h"
 #include "base/metrics/histogram_macros.h"
-#include "base/sequenced_task_runner.h"
 #include "base/task/post_task.h"
+#include "base/task/sequenced_task_runner.h"
 #include "base/task/task_traits.h"
 #include "net/dns/dns_config_service.h"
 
@@ -94,7 +94,7 @@ NetworkChangeNotifierMac::GetCurrentConnectionType() const {
   base::TimeDelta remaining_time =
       base::Seconds(kMaxWaitForConnectionTypeInSeconds);
   base::TimeTicks end_time = base::TimeTicks::Now() + remaining_time;
-  while (remaining_time > base::TimeDelta()) {
+  while (remaining_time.is_positive()) {
     initial_connection_type_cv_.TimedWait(remaining_time);
     if (connection_type_initialized_)
       return connection_type_;
