@@ -64,27 +64,6 @@ class NET_EXPORT ParsedCertificate
       std::vector<scoped_refptr<net::ParsedCertificate>>* chain,
       CertErrors* errors);
 
-  // Like Create() this builds a ParsedCertificate given a DER-encoded
-  // Certificate and returns nullptr on failure.
-  //
-  // However a copy of |data| is NOT made.
-  //
-  // This is a dangerous way to create as ParsedCertificate and should only be
-  // used with care when saving a copy is really worth it, or the data is known
-  // to come from static storage (and hence remain valid for entire life of
-  // process).
-  //
-  // ParsedCertificate is reference counted, so it is easy to extend the life
-  // and and end up with a ParsedCertificate referencing feed memory.
-  //
-  // On either success or failure, if |errors| is non-null it may have error
-  // information added to it.
-  static scoped_refptr<ParsedCertificate> CreateWithoutCopyingUnsafe(
-      const uint8_t* data,
-      size_t length,
-      const ParseCertificateOptions& options,
-      CertErrors* errors);
-
   ParsedCertificate(const ParsedCertificate&) = delete;
   ParsedCertificate& operator=(const ParsedCertificate&) = delete;
 
@@ -268,18 +247,7 @@ class NET_EXPORT ParsedCertificate
   ParsedCertificate();
   ~ParsedCertificate();
 
-  // Creates a ParsedCertificate.  If |backing_data| is non-null, the
-  // certificate's DER-encoded data will be referenced from here. Otherwise the
-  // certificate's data will be |static_data|, and the pointer MUST remain
-  // valid and its data unmodified for the entirety of the program.
-  static scoped_refptr<ParsedCertificate> CreateInternal(
-      bssl::UniquePtr<CRYPTO_BUFFER> backing_data,
-      der::Input static_data,
-      const ParseCertificateOptions& options,
-      CertErrors* errors);
-
-  // The backing store for the certificate data. May be null if created by
-  // CreateWithoutCopyingUnsafe.
+  // The backing store for the certificate data.
   bssl::UniquePtr<CRYPTO_BUFFER> cert_data_;
 
   // Points to the raw certificate DER.
