@@ -133,7 +133,7 @@ void NSSCertDatabase::ListCertsInfo(ListCertsInfoCallback callback) {
       std::move(callback));
 }
 
-#if BUILDFLAG(IS_CHROMEOS_ASH)
+#if defined(OS_CHROMEOS)
 crypto::ScopedPK11Slot NSSCertDatabase::GetSystemSlot() const {
   return crypto::ScopedPK11Slot();
 }
@@ -146,7 +146,7 @@ bool NSSCertDatabase::IsCertificateOnSlot(CERTCertificate* cert,
 
   return PK11_FindCertInSlot(slot, cert, nullptr) != CK_INVALID_HANDLE;
 }
-#endif
+#endif  // defined(OS_CHROMEOS)
 
 crypto::ScopedPK11Slot NSSCertDatabase::GetPublicSlot() const {
   return crypto::ScopedPK11Slot(PK11_ReferenceSlot(public_slot_.get()));
@@ -198,14 +198,9 @@ int NSSCertDatabase::ImportFromPKCS12(
     const std::u16string& password,
     bool is_extractable,
     ScopedCERTCertificateList* imported_certs) {
-  DVLOG(1) << __func__ << " "
-           << PK11_GetModuleID(slot_info) << ":"
-           << PK11_GetSlotID(slot_info);
-  int result = psm::nsPKCS12Blob_Import(slot_info,
-                                        data.data(), data.size(),
-                                        password,
-                                        is_extractable,
-                                        imported_certs);
+  int result =
+      psm::nsPKCS12Blob_Import(slot_info, data.data(), data.size(), password,
+                               is_extractable, imported_certs);
   if (result == OK)
     NotifyObserversCertDBChanged();
 
@@ -438,6 +433,13 @@ bool NSSCertDatabase::IsReadOnly(const CERTCertificate* cert) {
 }
 
 // static
+// `cfi-icall` is a clang flag to enable extra checks to prevent "Indirect call
+// of a function with wrong dynamic type". To work properly it requires the
+// called function or the function taking the address of the called function
+// to be compiled with "-fsanitize=cfi-icall" that is not true for libnss3.
+// Because of that we are getting a false positive result around using the
+// dynamically loaded `pk11_has_attribute_set` method.
+NO_SANITIZE("cfi-icall")
 bool NSSCertDatabase::IsHardwareBacked(const CERTCertificate* cert) {
   PK11SlotInfo* slot = cert->slot;
   if (!slot)
