@@ -13,14 +13,11 @@
 #include "base/task/post_task.h"
 #include "base/values.h"
 #include "build/build_config.h"
-#include "crypto/sha2.h"
 #include "net/base/net_errors.h"
 #include "net/cert/cert_verify_proc.h"
 #include "net/cert/cert_verify_result.h"
-#include "net/cert/ev_root_ca_metadata.h"
-#include "net/cert/internal/cert_errors.h"
-#include "net/cert/internal/parsed_certificate.h"
 #include "net/cert/multi_threaded_cert_verifier.h"
+#include "net/cert/trial_comparison_cert_verifier_util.h"
 #include "net/cert/x509_util.h"
 #include "net/log/net_log.h"
 #include "net/log/net_log_event_type.h"
@@ -37,91 +34,6 @@ base::Value JobResultParams(bool trial_success) {
   return results;
 }
 
-// Note: This ignores the result of stapled OCSP (which is the same for both
-// verifiers) and informational statuses about the certificate algorithms and
-// the hashes, since they will be the same if the certificate chains are the
-// same.
-bool CertVerifyResultEqual(const CertVerifyResult& a,
-                           const CertVerifyResult& b) {
-  return std::tie(a.cert_status, a.is_issued_by_known_root) ==
-             std::tie(b.cert_status, b.is_issued_by_known_root) &&
-         (!!a.verified_cert == !!b.verified_cert) &&
-         (!a.verified_cert ||
-          a.verified_cert->EqualsIncludingChain(b.verified_cert.get()));
-}
-
-scoped_refptr<ParsedCertificate> ParsedCertificateFromBuffer(
-    CRYPTO_BUFFER* cert_handle,
-    CertErrors* errors) {
-  return ParsedCertificate::Create(bssl::UpRef(cert_handle),
-                                   x509_util::DefaultParseCertificateOptions(),
-                                   errors);
-}
-
-ParsedCertificateList ParsedCertificateListFromX509Certificate(
-    const X509Certificate* cert) {
-  CertErrors parsing_errors;
-
-  ParsedCertificateList certs;
-  scoped_refptr<ParsedCertificate> target =
-      ParsedCertificateFromBuffer(cert->cert_buffer(), &parsing_errors);
-  if (!target)
-    return {};
-  certs.push_back(target);
-
-  for (const auto& buf : cert->intermediate_buffers()) {
-    scoped_refptr<ParsedCertificate> intermediate =
-        ParsedCertificateFromBuffer(buf.get(), &parsing_errors);
-    if (!intermediate)
-      return {};
-    certs.push_back(intermediate);
-  }
-
-  return certs;
-}
-
-// Tests whether cert has multiple EV policies, and at least one matches the
-// root. This is not a complete test of EV, but just enough to give a possible
-// explanation as to why the platform verifier did not validate as EV while
-// builtin did. (Since only the builtin verifier correctly handles multiple
-// candidate EV policies.)
-bool CertHasMultipleEVPoliciesAndOneMatchesRoot(const X509Certificate* cert) {
-  if (cert->intermediate_buffers().empty())
-    return false;
-
-  ParsedCertificateList certs = ParsedCertificateListFromX509Certificate(cert);
-  if (certs.empty())
-    return false;
-
-  ParsedCertificate* leaf = certs.front().get();
-  ParsedCertificate* root = certs.back().get();
-
-  if (!leaf->has_policy_oids())
-    return false;
-
-  const EVRootCAMetadata* ev_metadata = EVRootCAMetadata::GetInstance();
-  std::set<der::Input> candidate_oids;
-  for (const der::Input& oid : leaf->policy_oids()) {
-    if (ev_metadata->IsEVPolicyOIDGivenBytes(oid))
-      candidate_oids.insert(oid);
-  }
-
-  if (candidate_oids.size() <= 1)
-    return false;
-
-  SHA256HashValue root_fingerprint;
-  crypto::SHA256HashString(root->der_cert().AsStringPiece(),
-                           root_fingerprint.data,
-                           sizeof(root_fingerprint.data));
-
-  for (const der::Input& oid : candidate_oids) {
-    if (ev_metadata->HasEVPolicyOIDGivenBytes(root_fingerprint, oid))
-      return true;
-  }
-
-  return false;
-}
-
 }  // namespace
 
 // The Job represents the state machine for a trial cert verification.
@@ -190,16 +102,6 @@ class TrialComparisonCertVerifier::Job {
   // that re-verification completes.
   void OnPrimaryReverifyWithSecondaryChainCompleted(int result);
 
-  // Check if the differences between the primary and trial verifiers can be
-  // ignored. This only handles differences that can be checked synchronously.
-  // If the difference is ignorable, returns the relevant TrialComparisonResult,
-  // otherwise returns kInvalid.
-  TrialComparisonResult IsSynchronouslyIgnorableDifference(
-      int primary_error,
-      const CertVerifyResult& primary_result,
-      int trial_error,
-      const CertVerifyResult& trial_result);
-
   const CertVerifier::Config config_;
   bool config_changed_ = false;
   const CertVerifier::RequestParams params_;
@@ -386,16 +288,16 @@ void TrialComparisonCertVerifier::Job::FinishWithError() {
   DCHECK(trial_error_ != primary_error_ ||
          !CertVerifyResultEqual(trial_result_, primary_result_));
 
-  TrialComparisonResult result_code = kInvalid;
+  TrialComparisonResult result_code = TrialComparisonResult::kInvalid;
 
   if (primary_error_ == OK && trial_error_ == OK) {
-    result_code = kBothValidDifferentDetails;
+    result_code = TrialComparisonResult::kBothValidDifferentDetails;
   } else if (primary_error_ == OK) {
-    result_code = kPrimaryValidSecondaryError;
+    result_code = TrialComparisonResult::kPrimaryValidSecondaryError;
   } else if (trial_error_ == OK) {
-    result_code = kPrimaryErrorSecondaryValid;
+    result_code = TrialComparisonResult::kPrimaryErrorSecondaryValid;
   } else {
-    result_code = kBothErrorDifferentDetails;
+    result_code = TrialComparisonResult::kBothErrorDifferentDetails;
   }
   Finish(/*is_success=*/false, result_code);
 }
@@ -461,7 +363,7 @@ void TrialComparisonCertVerifier::Job::OnTrialJobCompleted(int result) {
 
   if (trial_success) {
     // Note: Will delete |this|.
-    FinishSuccess(kEqual);
+    FinishSuccess(TrialComparisonResult::kEqual);
     return;
   }
 
@@ -472,7 +374,7 @@ void TrialComparisonCertVerifier::Job::OnTrialJobCompleted(int result) {
         (CERT_STATUS_REVOKED | CERT_STATUS_REV_CHECKING_ENABLED))) {
     if (config_changed_) {
       // Note: Will delete |this|.
-      FinishSuccess(kIgnoredConfigurationChanged);
+      FinishSuccess(TrialComparisonResult::kIgnoredConfigurationChanged);
       return;
     }
 
@@ -492,13 +394,22 @@ void TrialComparisonCertVerifier::Job::OnTrialJobCompleted(int result) {
   }
 #endif
 
+  TrialComparisonResult ignorable_difference =
+      IsSynchronouslyIgnorableDifference(primary_error_, primary_result_,
+                                         trial_error_, trial_result_,
+                                         config_.enable_sha1_local_anchors);
+  if (ignorable_difference != TrialComparisonResult::kInvalid) {
+    FinishSuccess(ignorable_difference);  // Note: Will delete |this|.
+    return;
+  }
+
   const bool chains_equal = primary_result_.verified_cert->EqualsIncludingChain(
       trial_result_.verified_cert.get());
 
   if (!chains_equal && (trial_error_ == OK || primary_error_ != OK)) {
     if (config_changed_) {
       // Note: Will delete |this|.
-      FinishSuccess(kIgnoredConfigurationChanged);
+      FinishSuccess(TrialComparisonResult::kIgnoredConfigurationChanged);
       return;
     }
 
@@ -520,14 +431,6 @@ void TrialComparisonCertVerifier::Job::OnTrialJobCompleted(int result) {
     return;
   }
 
-  TrialComparisonResult ignorable_difference =
-      IsSynchronouslyIgnorableDifference(primary_error_, primary_result_,
-                                         trial_error_, trial_result_);
-  if (ignorable_difference != kInvalid) {
-    FinishSuccess(ignorable_difference);  // Note: Will delete |this|.
-    return;
-  }
-
   FinishWithError();  // Note: Will delete |this|.
 }
 
@@ -536,7 +439,8 @@ void TrialComparisonCertVerifier::Job::
     OnMacRevCheckingReverificationJobCompleted(int result) {
   if (result == ERR_CERT_REVOKED) {
     // Will delete |this|.
-    FinishSuccess(kIgnoredMacUndesiredRevocationChecking);
+    FinishSuccess(
+        TrialComparisonResult::kIgnoredMacUndesiredRevocationChecking);
     return;
   }
   FinishWithError();  // Note: Will delete |this|.
@@ -552,20 +456,23 @@ void TrialComparisonCertVerifier::Job::
     // Ignore the difference.
     //
     // Note: Will delete |this|.
-    FinishSuccess(kIgnoredDifferentPathReVerifiesEquivalent);
+    FinishSuccess(
+        TrialComparisonResult::kIgnoredDifferentPathReVerifiesEquivalent);
     return;
   }
 
   if (IsSynchronouslyIgnorableDifference(result, reverification_result_,
-                                         trial_error_,
-                                         trial_result_) != kInvalid) {
+                                         trial_error_, trial_result_,
+                                         config_.enable_sha1_local_anchors) !=
+      TrialComparisonResult::kInvalid) {
     // The new result matches if ignoring differences. Still use the
     // |kIgnoredDifferentPathReVerifiesEquivalent| code rather than the result
     // of IsSynchronouslyIgnorableDifference, since it's the higher level
     // description of what the difference is in this case.
     //
     // Note: Will delete |this|.
-    FinishSuccess(kIgnoredDifferentPathReVerifiesEquivalent);
+    FinishSuccess(
+        TrialComparisonResult::kIgnoredDifferentPathReVerifiesEquivalent);
     return;
   }
 
@@ -573,39 +480,6 @@ void TrialComparisonCertVerifier::Job::
   FinishWithError();
 }
 
-TrialComparisonCertVerifier::TrialComparisonResult
-TrialComparisonCertVerifier::Job::IsSynchronouslyIgnorableDifference(
-    int primary_error,
-    const CertVerifyResult& primary_result,
-    int trial_error,
-    const CertVerifyResult& trial_result) {
-  DCHECK(primary_result.verified_cert);
-  DCHECK(trial_result.verified_cert);
-
-  if (primary_error == OK &&
-      primary_result.verified_cert->intermediate_buffers().empty()) {
-    // Platform may support trusting a leaf certificate directly. Builtin
-    // verifier does not. See https://crbug.com/814994.
-    return kIgnoredLocallyTrustedLeaf;
-  }
-
-  const bool chains_equal = primary_result.verified_cert->EqualsIncludingChain(
-      trial_result.verified_cert.get());
-
-  if (chains_equal && (trial_result.cert_status & CERT_STATUS_IS_EV) &&
-      !(primary_result.cert_status & CERT_STATUS_IS_EV) &&
-      (primary_error == trial_error)) {
-    // The platform CertVerifyProc impls only check a single potential EV
-    // policy from the leaf.  If the leaf had multiple policies, builtin
-    // verifier may verify it as EV when the platform verifier did not.
-    if (CertHasMultipleEVPoliciesAndOneMatchesRoot(
-            trial_result.verified_cert.get())) {
-      return kIgnoredMultipleEVPoliciesAndOneMatchesRoot;
-    }
-  }
-  return kInvalid;
-}
-
 TrialComparisonCertVerifier::Job::Request::Request(
     TrialComparisonCertVerifier::Job* parent,
     CertVerifyResult* client_result,
