@@ -68,8 +68,8 @@
 #include "base/macros.h"
 #include "base/memory/ptr_util.h"
 #include "base/numerics/safe_math.h"
-#include "base/single_thread_task_runner.h"
 #include "base/synchronization/waitable_event.h"
+#include "base/task/single_thread_task_runner.h"
 #include "base/threading/thread_task_runner_handle.h"
 #include "base/timer/timer.h"
 #include "net/base/io_buffer.h"
@@ -537,7 +537,7 @@ void Job::StartURLRequest(URLRequestContext* context) {
   url_request_->Start();
 
   // Start a timer to limit how long the job runs for.
-  if (request_params_->timeout > base::TimeDelta()) {
+  if (request_params_->timeout.is_positive()) {
     timer_.Start(FROM_HERE, request_params_->timeout,
                  base::BindOnce(&Job::FailRequest, base::Unretained(this),
                                 ERR_TIMED_OUT));
