@@ -759,7 +759,7 @@ std::unique_ptr<CanonicalCookie> CanonicalCookie::FromStorage(
       creation, expiration, last_access, secure, httponly, same_site, priority,
       same_party, partition_key, source_scheme, source_port));
 
-  if (cc->IsCanonical()) {
+  if (cc->IsCanonicalForFromStorage()) {
     // This will help capture the number of times a cookie is canonical but does
     // not have a valid name+value size length
     bool valid_cookie_name_value_pair =
@@ -1154,10 +1154,6 @@ CookieAccessResult CanonicalCookie::IsSetPermittedInContext(
     access_result.status.AddExclusionReason(
         CookieInclusionStatus::EXCLUDE_SAMESITE_NONE_INSECURE);
   }
-  // Log whether a SameSite=None cookie is Secure or not.
-  if (SameSite() == CookieSameSite::NO_RESTRICTION) {
-    UMA_HISTOGRAM_BOOLEAN("Cookie.SameSiteNoneIsSecure", IsSecure());
-  }
 
   // For LEGACY cookies we should always return the schemeless context,
   // otherwise let GetContextForCookieInclusion() decide.
@@ -1328,15 +1324,19 @@ bool CanonicalCookie::PartialCompare(const CanonicalCookie& other) const {
 }
 
 bool CanonicalCookie::IsCanonical() const {
-  // Not checking domain or path against ParsedCookie as it may have
-  // come purely from the URL. Also, don't call IsValidCookieNameValuePair()
-  // here because we don't want to enforce the size checks on names or values
-  // that may have been reconstituted from the cookie store.
   // TODO(crbug.com/1244172) Eventually we should check the size of name+value,
   // assuming we collect metrics and determine that a low percentage of cookies
   // would fail this check. Note that we still don't want to enforce length
   // checks on domain or path for the reason stated above.
 
+  return IsCanonicalForFromStorage();
+}
+
+bool CanonicalCookie::IsCanonicalForFromStorage() const {
+  // Not checking domain or path against ParsedCookie as it may have
+  // come purely from the URL. Also, don't call IsValidCookieNameValuePair()
+  // here because we don't want to enforce the size checks on names or values
+  // that may have been reconstituted from the cookie store.
   if (ParsedCookie::ParseTokenString(name_) != name_ ||
       !ParsedCookie::ValueMatchesParsedValue(value_)) {
     return false;
