@@ -185,9 +185,9 @@ std::string HttpssvcMetrics::BuildMetricName(
 void HttpssvcMetrics::RecordMetrics() {
   // The HTTPSSVC experiment and its feature param indicating INTEGRITY must
   // both be enabled.
-  DCHECK(base::FeatureList::IsEnabled(features::kDnsHttpssvc));
   DCHECK(features::kDnsHttpssvcUseIntegrity.Get() ||
-         features::kDnsHttpssvcUseHttpssvc.Get());
+         features::kDnsHttpssvcUseHttpssvc.Get() ||
+         base::FeatureList::IsEnabled(features::kUseDnsHttpsSvcb));
 
   DCHECK(!already_recorded_);
   already_recorded_ = true;
