@@ -8,7 +8,7 @@
 #include <list>
 #include <set>
 
-#include "base/containers/mru_cache.h"
+#include "base/containers/lru_cache.h"
 #include "base/memory/weak_ptr.h"
 #include "base/time/time.h"
 #include "base/timer/timer.h"
@@ -47,11 +47,11 @@ typedef std::list<std::pair<BrokenAlternativeService, base::TimeTicks>>
 
 // Stores how many times an alternative service has been marked broken.
 class RecentlyBrokenAlternativeServices
-    : public base::MRUCache<BrokenAlternativeService, int> {
+    : public base::LRUCache<BrokenAlternativeService, int> {
  public:
   RecentlyBrokenAlternativeServices(
       int max_recently_broken_alternative_service_entries)
-      : base::MRUCache<BrokenAlternativeService, int>(
+      : base::LRUCache<BrokenAlternativeService, int>(
             max_recently_broken_alternative_service_entries) {}
 };
 
