@@ -21,11 +21,11 @@
 #include "base/metrics/field_trial.h"
 #include "base/metrics/histogram_macros.h"
 #include "base/pickle.h"
-#include "base/single_thread_task_runner.h"
 #include "base/strings/strcat.h"
 #include "base/strings/string_number_conversions.h"
 #include "base/strings/string_util.h"
 #include "base/strings/stringprintf.h"
+#include "base/task/single_thread_task_runner.h"
 #include "base/threading/thread_task_runner_handle.h"
 #include "base/time/default_clock.h"
 #include "base/time/time.h"
@@ -448,6 +448,33 @@ std::string HttpCache::GetResourceURLFromHttpCacheKey(const std::string& key) {
   return key.substr(pos);
 }
 
+Error HttpCache::CheckResourceExistence(
+    const GURL& url,
+    const base::StringPiece method,
+    const NetworkIsolationKey& network_isolation_key,
+    bool is_subframe,
+    base::OnceCallback<void(Error)> callback) {
+  if (!disk_cache_)
+    return ERR_CACHE_MISS;
+
+  HttpRequestInfo request_info;
+  request_info.url = url;
+  request_info.method = std::string(method);
+  request_info.network_isolation_key = network_isolation_key;
+  request_info.is_subframe_document_resource = is_subframe;
+
+  std::string key = GenerateCacheKey(&request_info);
+  disk_cache::EntryResult entry_result = disk_cache_->OpenEntry(
+      key, net::IDLE,
+      base::BindOnce(&HttpCache::ResourceExistenceCheckCallback, GetWeakPtr(),
+                     std::move(callback)));
+
+  if (entry_result.net_error() == OK && !entry_result.opened())
+    return ERR_CACHE_MISS;
+
+  return entry_result.net_error();
+}
+
 // static
 std::string HttpCache::GenerateCacheKeyForTest(const HttpRequestInfo* request) {
   return GenerateCacheKey(request);
@@ -1511,4 +1538,13 @@ void HttpCache::OnBackendCreated(int result, PendingOp* pending_op) {
     item->NotifyTransaction(result, nullptr);
 }
 
+void HttpCache::ResourceExistenceCheckCallback(
+    base::OnceCallback<void(Error)> callback,
+    disk_cache::EntryResult entry_result) {
+  Error result = (entry_result.net_error() == OK && entry_result.opened())
+                     ? OK
+                     : ERR_CACHE_MISS;
+  std::move(callback).Run(result);
+}
+
 }  // namespace net
