@@ -21,6 +21,7 @@
 #include <unordered_map>
 #include <unordered_set>
 
+#include "base/callback.h"
 #include "base/files/file_path.h"
 #include "base/gtest_prod_util.h"
 #include "base/memory/weak_ptr.h"
@@ -280,6 +281,12 @@ class NET_EXPORT HttpCache : public HttpTransactionFactory {
   // Resets g_init_cache and g_enable_split_cache for tests.
   static void ClearGlobalsForTesting();
 
+  Error CheckResourceExistence(const GURL& url,
+                               const base::StringPiece method,
+                               const NetworkIsolationKey& network_isolation_key,
+                               bool is_subframe,
+                               base::OnceCallback<void(Error)>);
+
  private:
   // Types --------------------------------------------------------------------
 
@@ -635,6 +642,9 @@ class NET_EXPORT HttpCache : public HttpTransactionFactory {
   // Processes the backend creation notification.
   void OnBackendCreated(int result, PendingOp* pending_op);
 
+  void ResourceExistenceCheckCallback(base::OnceCallback<void(Error)> callback,
+                                      disk_cache::EntryResult entry_result);
+
   // Constants ----------------------------------------------------------------
 
   // Used when generating and accessing keys if cache is split.
