@@ -32,6 +32,10 @@ class IOBuffer;
 class PartialData {
  public:
   PartialData();
+
+  PartialData(const PartialData&) = delete;
+  PartialData& operator=(const PartialData&) = delete;
+
   ~PartialData();
 
   // Performs initialization of the object by examining the request |headers|
@@ -159,8 +163,6 @@ class PartialData {
   bool initial_validation_;  // Only used for truncated entries.
   CompletionOnceCallback callback_;
   base::WeakPtrFactory<PartialData> weak_factory_{this};
-
-  DISALLOW_COPY_AND_ASSIGN(PartialData);
 };
 
 }  // namespace net
