@@ -39,15 +39,13 @@ class TestNetworkQualityEstimator : public NetworkQualityEstimator {
   TestNetworkQualityEstimator(
       const std::map<std::string, std::string>& variation_params,
       bool allow_local_host_requests_for_tests,
-      bool allow_smaller_responses_for_tests,
-      std::unique_ptr<RecordingBoundTestNetLog> net_log);
+      bool allow_smaller_responses_for_tests);
 
   TestNetworkQualityEstimator(
       const std::map<std::string, std::string>& variation_params,
       bool allow_local_host_requests_for_tests,
       bool allow_smaller_responses_for_tests,
-      bool suppress_notifications_for_testing,
-      std::unique_ptr<RecordingBoundTestNetLog> net_log);
+      bool suppress_notifications_for_testing);
 
   explicit TestNetworkQualityEstimator(
       std::unique_ptr<NetworkQualityEstimatorParams> params);
@@ -236,18 +234,14 @@ class TestNetworkQualityEstimator : public NetworkQualityEstimator {
     explicit LocalHttpTestServer(const base::FilePath& document_root);
   };
 
-  TestNetworkQualityEstimator(
-      std::unique_ptr<NetworkQualityEstimatorParams> params,
-      std::unique_ptr<RecordingBoundTestNetLog> net_log);
-
   // NetworkQualityEstimator implementation that returns the overridden
   // network id and signal strength (instead of invoking platform APIs).
   nqe::internal::NetworkID GetCurrentNetworkID() const override;
 
   absl::optional<net::EffectiveConnectionType> GetOverrideECT() const override;
 
-  // Net log provided to network quality estimator.
-  std::unique_ptr<net::RecordingBoundTestNetLog> net_log_;
+  // Net log observer used to test correctness of NetLog entries.
+  net::RecordingNetLogObserver net_log_observer_;
 
   // If set, GetEffectiveConnectionType() and GetRecentEffectiveConnectionType()
   // would return the set values, respectively.
