@@ -19,6 +19,10 @@ class QUIC_EXPORT_PRIVATE QuicChromiumClock : public QuicClock {
   static QuicChromiumClock* GetInstance();
 
   QuicChromiumClock();
+
+  QuicChromiumClock(const QuicChromiumClock&) = delete;
+  QuicChromiumClock& operator=(const QuicChromiumClock&) = delete;
+
   ~QuicChromiumClock() override;
 
   // QuicClock implementation:
@@ -29,9 +33,6 @@ class QUIC_EXPORT_PRIVATE QuicChromiumClock : public QuicClock {
   // Converts a QuicTime returned by QuicChromiumClock to base::TimeTicks.
   // Helper functions to safely convert between QuicTime and TimeTicks.
   static base::TimeTicks QuicTimeToTimeTicks(QuicTime quic_time);
-
- private:
-  DISALLOW_COPY_AND_ASSIGN(QuicChromiumClock);
 };
 
 }  // namespace quic
