@@ -13,6 +13,9 @@ namespace quic {
 
 class QUIC_EXPORT_PRIVATE QuicHostnameUtilsImpl {
  public:
+  QuicHostnameUtilsImpl(const QuicHostnameUtilsImpl&) = delete;
+  QuicHostnameUtilsImpl& operator=(const QuicHostnameUtilsImpl&) = delete;
+
   // Returns true if the sni is valid, false otherwise.
   //  (1) disallow IP addresses;
   //  (2) check that the hostname contains valid characters only; and
@@ -22,9 +25,6 @@ class QUIC_EXPORT_PRIVATE QuicHostnameUtilsImpl {
   // Convert hostname to lowercase and remove the trailing '.'.
   // WARNING: mutates |hostname| in place and returns |hostname|.
   static std::string NormalizeHostname(absl::string_view hostname);
-
- private:
-  DISALLOW_COPY_AND_ASSIGN(QuicHostnameUtilsImpl);
 };
 
 }  // namespace quic
