@@ -19,7 +19,7 @@
 #include <vector>
 
 #include "base/containers/flat_map.h"
-#include "base/containers/mru_cache.h"
+#include "base/containers/lru_cache.h"
 #include "base/macros.h"
 #include "base/observer_list_types.h"
 #include "base/strings/string_piece.h"
