@@ -212,11 +212,9 @@ void ClientSocketPoolManager::set_max_sockets_per_proxy_server(
 // static
 base::TimeDelta ClientSocketPoolManager::unused_idle_socket_timeout(
     HttpNetworkSession::SocketPoolType pool_type) {
-  return base::TimeDelta::FromSeconds(base::GetFieldTrialParamByFeatureAsInt(
+  return base::Seconds(base::GetFieldTrialParamByFeatureAsInt(
       net::features::kNetUnusedIdleSocketTimeout,
-      "unused_idle_socket_timeout_seconds",
-      60
-      ));
+      "unused_idle_socket_timeout_seconds", 60));
 }
 
 int InitSocketHandleForHttpRequest(
