@@ -47,6 +47,9 @@ class NET_EXPORT_PRIVATE SSLSocketParams
                   PrivacyMode privacy_mode,
                   NetworkIsolationKey network_isolation_key);
 
+  SSLSocketParams(const SSLSocketParams&) = delete;
+  SSLSocketParams& operator=(const SSLSocketParams&) = delete;
+
   // Returns the type of the underlying connection.
   ConnectionType GetConnectionType() const;
 
@@ -78,8 +81,6 @@ class NET_EXPORT_PRIVATE SSLSocketParams
   const SSLConfig ssl_config_;
   const PrivacyMode privacy_mode_;
   const NetworkIsolationKey network_isolation_key_;
-
-  DISALLOW_COPY_AND_ASSIGN(SSLSocketParams);
 };
 
 // SSLConnectJob establishes a connection, through a proxy if needed, and then
@@ -109,6 +110,10 @@ class NET_EXPORT_PRIVATE SSLConnectJob : public ConnectJob,
                 scoped_refptr<SSLSocketParams> params,
                 ConnectJob::Delegate* delegate,
                 const NetLogWithSource* net_log);
+
+  SSLConnectJob(const SSLConnectJob&) = delete;
+  SSLConnectJob& operator=(const SSLConnectJob&) = delete;
+
   ~SSLConnectJob() override;
 
   // ConnectJob methods.
@@ -201,8 +206,6 @@ class NET_EXPORT_PRIVATE SSLConnectJob : public ConnectJob,
   // limited lifetime and the aliases can no longer be retrieved from there by
   // by the time that the aliases are needed to be passed in SetSocket.
   std::vector<std::string> dns_aliases_;
-
-  DISALLOW_COPY_AND_ASSIGN(SSLConnectJob);
 };
 
 }  // namespace net
