@@ -9,7 +9,6 @@
 
 #include "base/bind.h"
 #include "base/callback_helpers.h"
-#include "base/lazy_instance.h"
 #include "base/logging.h"
 #include "base/memory/weak_ptr.h"
 #include "base/strings/string_util.h"
@@ -43,27 +42,6 @@ namespace {
 // overlap with any value of the net::Error range, including net::OK).
 const int kSSLServerSocketNoPendingResult = 1;
 
-class SocketDataIndex {
- public:
-  static SocketDataIndex* GetInstance();
-  SocketDataIndex() {
-    ssl_socket_data_index_ =
-        SSL_get_ex_new_index(0, nullptr, nullptr, nullptr, nullptr);
-  }
-
-  // This is the index used with SSL_get_ex_data to retrieve the owner
-  // SSLServerSocketImpl object from an SSL instance.
-  int ssl_socket_data_index_;
-};
-
-base::LazyInstance<SocketDataIndex>::Leaky g_ssl_socket_data_index_ =
-    LAZY_INSTANCE_INITIALIZER;
-
-// static
-SocketDataIndex* SocketDataIndex::GetInstance() {
-  return g_ssl_socket_data_index_.Pointer();
-}
-
 }  // namespace
 
 class SSLServerContextImpl::SocketImpl : public SSLServerSocket,
@@ -121,6 +99,8 @@ class SSLServerContextImpl::SocketImpl : public SSLServerSocket,
   int64_t GetTotalReceivedBytes() const override;
   void ApplySocketTag(const SocketTag& tag) override;
 
+  static SocketImpl* FromSSL(SSL* ssl);
+
   static ssl_verify_result_t CertVerifyCallback(SSL* ssl, uint8_t* out_alert);
   ssl_verify_result_t CertVerifyCallbackImpl(uint8_t* out_alert);
 
@@ -161,6 +141,9 @@ class SSLServerContextImpl::SocketImpl : public SSLServerSocket,
                                 unsigned in_len,
                                 void* arg);
 
+  static ssl_select_cert_result_t SelectCertificateCallback(
+      const SSL_CLIENT_HELLO* client_hello);
+
   // SocketBIOAdapter::Delegate implementation.
   void OnReadReady() override;
   void OnWriteReady() override;
@@ -237,11 +220,7 @@ SSLServerContextImpl::SocketImpl::SocketImpl(
       transport_socket_(std::move(transport_socket)),
       next_handshake_state_(STATE_NONE),
       completed_handshake_(false),
-      negotiated_protocol_(kProtoUnknown) {
-  ssl_.reset(SSL_new(context_->ssl_ctx_.get()));
-  SSL_set_app_data(ssl_.get(), this);
-  SSL_set_shed_handshake_config(ssl_.get(), 1);
-}
+      negotiated_protocol_(kProtoUnknown) {}
 
 SSLServerContextImpl::SocketImpl::~SocketImpl() {
   if (ssl_) {
@@ -269,13 +248,8 @@ SSLServerContextImpl::SocketImpl::PrivateKeySignCallback(SSL* ssl,
                                                          uint16_t algorithm,
                                                          const uint8_t* in,
                                                          size_t in_len) {
-  DCHECK(ssl);
-  SSLServerContextImpl::SocketImpl* socket =
-      static_cast<SSLServerContextImpl::SocketImpl*>(SSL_get_ex_data(
-          ssl, SocketDataIndex::GetInstance()->ssl_socket_data_index_));
-  DCHECK(socket);
-  return socket->PrivateKeySignCallback(out, out_len, max_out, algorithm, in,
-                                        in_len);
+  return FromSSL(ssl)->PrivateKeySignCallback(out, out_len, max_out, algorithm,
+                                              in, in_len);
 }
 
 // static
@@ -296,12 +270,7 @@ SSLServerContextImpl::SocketImpl::PrivateKeyCompleteCallback(SSL* ssl,
                                                              uint8_t* out,
                                                              size_t* out_len,
                                                              size_t max_out) {
-  DCHECK(ssl);
-  SSLServerContextImpl::SocketImpl* socket =
-      static_cast<SSLServerContextImpl::SocketImpl*>(SSL_get_ex_data(
-          ssl, SocketDataIndex::GetInstance()->ssl_socket_data_index_));
-  DCHECK(socket);
-  return socket->PrivateKeyCompleteCallback(out, out_len, max_out);
+  return FromSSL(ssl)->PrivateKeyCompleteCallback(out, out_len, max_out);
 }
 
 ssl_private_key_result_t
@@ -360,9 +329,7 @@ int SSLServerContextImpl::SocketImpl::ALPNSelectCallback(SSL* ssl,
                                                          const uint8_t* in,
                                                          unsigned in_len,
                                                          void* arg) {
-  SSLServerContextImpl::SocketImpl* socket =
-      static_cast<SSLServerContextImpl::SocketImpl*>(SSL_get_ex_data(
-          ssl, SocketDataIndex::GetInstance()->ssl_socket_data_index_));
+  SSLServerContextImpl::SocketImpl* socket = FromSSL(ssl);
 
   // Iterate over the server protocols in preference order.
   for (NextProto server_proto :
@@ -399,6 +366,17 @@ int SSLServerContextImpl::SocketImpl::ALPNSelectCallback(SSL* ssl,
   return SSL_TLSEXT_ERR_NOACK;
 }
 
+ssl_select_cert_result_t
+SSLServerContextImpl::SocketImpl::SelectCertificateCallback(
+    const SSL_CLIENT_HELLO* client_hello) {
+  SSLServerContextImpl::SocketImpl* socket = FromSSL(client_hello->ssl);
+  const SSLServerConfig& config = socket->context_->ssl_server_config_;
+  if (!config.client_hello_callback_for_testing.is_null()) {
+    config.client_hello_callback_for_testing.Run(client_hello);
+  }
+  return ssl_select_cert_success;
+}
+
 int SSLServerContextImpl::SocketImpl::Handshake(
     CompletionOnceCallback callback) {
   net_log_.BeginEvent(NetLogEventType::SSL_SERVER_HANDSHAKE);
@@ -828,11 +806,12 @@ int SSLServerContextImpl::SocketImpl::Init() {
 
   crypto::OpenSSLErrStackTracer err_tracer(FROM_HERE);
 
-  if (!ssl_ ||
-      !SSL_set_ex_data(ssl_.get(),
-                       SocketDataIndex::GetInstance()->ssl_socket_data_index_,
-                       this))
+  ssl_.reset(SSL_new(context_->ssl_ctx_.get()));
+  if (!ssl_ || !SSL_set_app_data(ssl_.get(), this)) {
     return ERR_UNEXPECTED;
+  }
+
+  SSL_set_shed_handshake_config(ssl_.get(), 1);
 
   // Set certificate and private key.
   if (context_->pkey_) {
@@ -878,12 +857,18 @@ int SSLServerContextImpl::SocketImpl::Init() {
   return OK;
 }
 
+SSLServerContextImpl::SocketImpl* SSLServerContextImpl::SocketImpl::FromSSL(
+    SSL* ssl) {
+  SocketImpl* socket = reinterpret_cast<SocketImpl*>(SSL_get_app_data(ssl));
+  DCHECK(socket);
+  return socket;
+}
+
 // static
 ssl_verify_result_t SSLServerContextImpl::SocketImpl::CertVerifyCallback(
     SSL* ssl,
     uint8_t* out_alert) {
-  SocketImpl* socket = reinterpret_cast<SocketImpl*>(SSL_get_app_data(ssl));
-  return socket->CertVerifyCallbackImpl(out_alert);
+  return FromSSL(ssl)->CertVerifyCallbackImpl(out_alert);
 }
 
 ssl_verify_result_t SSLServerContextImpl::SocketImpl::CertVerifyCallbackImpl(
@@ -1068,6 +1053,9 @@ void SSLServerContextImpl::Init() {
     CHECK(SSL_CTX_set1_ech_keys(ssl_ctx_.get(),
                                 ssl_server_config_.ech_keys.get()));
   }
+
+  SSL_CTX_set_select_certificate_cb(ssl_ctx_.get(),
+                                    &SocketImpl::SelectCertificateCallback);
 }
 
 SSLServerContextImpl::~SSLServerContextImpl() = default;
