@@ -71,6 +71,9 @@ class NET_EXPORT_PRIVATE SpdyStream {
    public:
     Delegate() {}
 
+    Delegate(const Delegate&) = delete;
+    Delegate& operator=(const Delegate&) = delete;
+
     // Called when the request headers have been sent. Never called
     // for push streams. Must not cause the stream to be closed.
     virtual void OnHeadersSent() = 0;
@@ -121,9 +124,6 @@ class NET_EXPORT_PRIVATE SpdyStream {
 
    protected:
     virtual ~Delegate() {}
-
-   private:
-    DISALLOW_COPY_AND_ASSIGN(Delegate);
   };
 
   // SpdyStream constructor
@@ -136,6 +136,9 @@ class NET_EXPORT_PRIVATE SpdyStream {
              const NetLogWithSource& net_log,
              const NetworkTrafficAnnotationTag& traffic_annotation);
 
+  SpdyStream(const SpdyStream&) = delete;
+  SpdyStream& operator=(const SpdyStream&) = delete;
+
   ~SpdyStream();
 
   // Set the delegate, which must not be NULL. Must not be called more
@@ -555,8 +558,6 @@ class NET_EXPORT_PRIVATE SpdyStream {
   const NetworkTrafficAnnotationTag traffic_annotation_;
 
   base::WeakPtrFactory<SpdyStream> weak_ptr_factory_{this};
-
-  DISALLOW_COPY_AND_ASSIGN(SpdyStream);
 };
 
 }  // namespace net
