@@ -200,6 +200,7 @@ struct SpdySessionDependencies {
   SpdySession::TimeFunc time_func;
   bool enable_http2_alternative_service;
   bool enable_websocket_over_http2;
+  bool enable_http2_settings_grease;
   absl::optional<SpdySessionPool::GreasedHttp2Frame> greased_http2_frame;
   bool http2_end_stream_with_data_frame;
   NetLog* net_log;
@@ -207,6 +208,7 @@ struct SpdySessionDependencies {
   bool enable_early_data;
   bool key_auth_cache_server_entries_by_network_isolation_key;
   bool enable_priority_update;
+  bool go_away_on_ip_change;
 };
 
 class SpdyURLRequestContext : public URLRequestContext {
