@@ -14,6 +14,7 @@
 
 #include "base/base64.h"
 #include "base/bind.h"
+#include "base/callback_forward.h"
 #include "base/callback_helpers.h"
 #include "base/files/file_path.h"
 #include "base/files/file_util.h"
@@ -108,6 +109,37 @@ std::unique_ptr<HttpResponse> HandleEchoHeader(const std::string& url,
   return http_response;
 }
 
+// /echo-cookie-with-status?status=###
+// Responds with the given status code and echos the cookies sent in the request
+std::unique_ptr<HttpResponse> HandleEchoCookieWithStatus(
+    const std::string& url,
+    const HttpRequest& request) {
+  if (!ShouldHandle(request, url))
+    return nullptr;
+
+  auto http_response = std::make_unique<BasicHttpResponse>();
+
+  GURL request_url = request.GetURL();
+  RequestQuery query = ParseQuery(request_url);
+
+  int status_code = 400;
+  const auto given_status = query.find("status");
+
+  if (given_status != query.end() && !given_status->second.empty() &&
+      !base::StringToInt(given_status->second.front(), &status_code)) {
+    status_code = 400;
+  }
+
+  http_response->set_code(static_cast<HttpStatusCode>(status_code));
+
+  const auto given_cookie = request.headers.find("Cookie");
+  std::string content =
+      (given_cookie == request.headers.end()) ? "None" : given_cookie->second;
+  http_response->set_content(content);
+  http_response->set_content_type("text/plain");
+  return http_response;
+}
+
 // TODO(https://crbug.com/1138913): Remove when request handlers are
 // implementable in Android's embedded test server implementation
 std::unique_ptr<HttpResponse> HandleEchoCriticalHeader(
@@ -679,45 +711,19 @@ std::unique_ptr<HttpResponse> HandleSlowServer(const HttpRequest& request) {
   if (request_url.has_query())
     delay = std::atof(request_url.query().c_str());
 
-  auto http_response = std::make_unique<DelayedHttpResponse>(
-      base::TimeDelta::FromSecondsD(delay));
+  auto http_response =
+      std::make_unique<DelayedHttpResponse>(base::Seconds(delay));
   http_response->set_content_type("text/plain");
   http_response->set_content(base::StringPrintf("waited %.1f seconds", delay));
   return http_response;
 }
 
-// Never returns a response.
-class HungHttpResponse : public HttpResponse {
- public:
-  HungHttpResponse() = default;
-
-  void SendResponse(const SendBytesCallback& send,
-                    SendCompleteCallback done) override {}
-
- private:
-  DISALLOW_COPY_AND_ASSIGN(HungHttpResponse);
-};
-
 // /hung
 // Never returns a response.
 std::unique_ptr<HttpResponse> HandleHungResponse(const HttpRequest& request) {
-  return std::make_unique<HungHttpResponse>();
+  return std::make_unique<HungResponse>();
 }
 
-// Return headers, then hangs.
-class HungAfterHeadersHttpResponse : public HttpResponse {
- public:
-  HungAfterHeadersHttpResponse() = default;
-
-  void SendResponse(const SendBytesCallback& send,
-                    SendCompleteCallback done) override {
-    send.Run("HTTP/1.1 OK\r\n\r\n", base::DoNothing());
-  }
-
- private:
-  DISALLOW_COPY_AND_ASSIGN(HungAfterHeadersHttpResponse);
-};
-
 // /hung-after-headers
 // Never returns a response.
 std::unique_ptr<HttpResponse> HandleHungAfterHeadersResponse(
@@ -731,26 +737,34 @@ class ExabyteResponse : public BasicHttpResponse {
  public:
   ExabyteResponse() {}
 
-  void SendResponse(const SendBytesCallback& send,
-                    SendCompleteCallback done) override {
+  ExabyteResponse(const ExabyteResponse&) = delete;
+  ExabyteResponse& operator=(const ExabyteResponse&) = delete;
+
+  void SendResponse(base::WeakPtr<HttpResponseDelegate> delegate) override {
     // Use 10^18 bytes (exabyte) as the content length so that the client will
     // be expecting data.
-    send.Run("HTTP/1.1 200 OK\r\nContent-Length:1000000000000000000\r\n\r\n",
-             base::BindOnce(&ExabyteResponse::SendExabyte, send));
+    delegate->SendResponseHeaders(HTTP_OK, "OK",
+                                  {{"Content-Length", "1000000000000000000"}});
+    SendExabyte(delegate);
   }
 
  private:
   // Keeps sending the word "echo" over and over again. It can go further to
   // limit the response to exactly an exabyte, but it shouldn't be necessary
   // for the purpose of testing.
-  static void SendExabyte(const SendBytesCallback& send) {
-    base::ThreadTaskRunnerHandle::Get()->PostTask(
-        FROM_HERE,
-        base::BindOnce(send, "echo",
-                       base::BindOnce(&ExabyteResponse::SendExabyte, send)));
+  void SendExabyte(base::WeakPtr<HttpResponseDelegate> delegate) {
+    delegate->SendContents(
+        "echo", base::BindOnce(&ExabyteResponse::PostSendExabyteTask,
+                               weak_factory_.GetWeakPtr(), delegate));
   }
 
-  DISALLOW_COPY_AND_ASSIGN(ExabyteResponse);
+  void PostSendExabyteTask(base::WeakPtr<HttpResponseDelegate> delegate) {
+    base::ThreadTaskRunnerHandle::Get()->PostTask(
+        FROM_HERE, base::BindOnce(&ExabyteResponse::SendExabyte,
+                                  weak_factory_.GetWeakPtr(), delegate));
+  }
+
+  base::WeakPtrFactory<ExabyteResponse> weak_factory_{this};
 };
 
 // /exabyte_response
@@ -817,10 +831,8 @@ class DelayedChunkedHttpResponse : public HttpResponse {
   DelayedChunkedHttpResponse& operator=(const DelayedChunkedHttpResponse&) =
       delete;
 
-  void SendResponse(const SendBytesCallback& send,
-                    SendCompleteCallback done) override {
-    send_bytes_callback_ = send;
-    send_complete_callback_ = std::move(done);
+  void SendResponse(base::WeakPtr<HttpResponseDelegate> delegate) override {
+    delegate_ = delegate;
 
     base::SequencedTaskRunnerHandle::Get()->PostDelayedTask(
         FROM_HERE,
@@ -831,19 +843,16 @@ class DelayedChunkedHttpResponse : public HttpResponse {
 
  private:
   void SendHeaders() {
-    send_bytes_callback_.Run(
-        "HTTP/1.1 200 OK\r\n"
-        "Content-Type: text/plain\r\n"
-        "Connection: close\r\n"
-        "Transfer-Encoding: chunked\r\n\r\n",
-        base::BindOnce(&DelayedChunkedHttpResponse::PrepateToSendNextChunk,
-                       weak_ptr_factory_.GetWeakPtr()));
+    base::StringPairs headers = {{"Content-Type", "text/plain"},
+                                 {"Connection", "close"},
+                                 {"Transfer-Encoding", "chunked"}};
+    delegate_->SendResponseHeaders(HTTP_OK, "OK", headers);
+    PrepareToSendNextChunk();
   }
 
-  void PrepateToSendNextChunk() {
+  void PrepareToSendNextChunk() {
     if (remaining_chunks_ == 0) {
-      send_bytes_callback_.Run(CreateChunk(0 /* chunk_size */),
-                               std::move(send_complete_callback_));
+      delegate_->SendContentsAndFinish(CreateChunk(0 /* chunk_size */));
       return;
     }
 
@@ -857,9 +866,10 @@ class DelayedChunkedHttpResponse : public HttpResponse {
   void SendNextChunk() {
     DCHECK_GT(remaining_chunks_, 0);
     remaining_chunks_--;
-    send_bytes_callback_.Run(
+
+    delegate_->SendContents(
         CreateChunk(chunk_size_),
-        base::BindOnce(&DelayedChunkedHttpResponse::PrepateToSendNextChunk,
+        base::BindOnce(&DelayedChunkedHttpResponse::PrepareToSendNextChunk,
                        weak_ptr_factory_.GetWeakPtr()));
   }
 
@@ -876,8 +886,7 @@ class DelayedChunkedHttpResponse : public HttpResponse {
   int chunk_size_;
   int remaining_chunks_;
 
-  SendBytesCallback send_bytes_callback_;
-  SendCompleteCallback send_complete_callback_;
+  base::WeakPtr<HttpResponseDelegate> delegate_ = nullptr;
 
   base::WeakPtrFactory<DelayedChunkedHttpResponse> weak_ptr_factory_{this};
 };
@@ -905,9 +914,9 @@ std::unique_ptr<HttpResponse> HandleChunked(const HttpRequest& request) {
     CHECK(base::StringToInt(query.GetValue(), &value));
     CHECK_GE(value, 0);
     if (query.GetKey() == "waitBeforeHeaders") {
-      delay_before_headers = base::TimeDelta::FromMilliseconds(value);
+      delay_before_headers = base::Milliseconds(value);
     } else if (query.GetKey() == "waitBetweenChunks") {
-      delay_between_chunks = base::TimeDelta::FromMilliseconds(value);
+      delay_between_chunks = base::Milliseconds(value);
     } else if (query.GetKey() == "chunkSize") {
       // A 0-size chunk indicates completion.
       CHECK_LT(0, value);
@@ -939,6 +948,8 @@ void RegisterDefaultHandlers(EmbeddedTestServer* server) {
       PREFIXED_HANDLER("/cachetime", &HandleCacheTime));
   server->RegisterDefaultHandler(
       base::BindRepeating(&HandleEchoHeader, "/echoheader", "no-cache"));
+  server->RegisterDefaultHandler(base::BindRepeating(
+      &HandleEchoCookieWithStatus, "/echo-cookie-with-status"));
   server->RegisterDefaultHandler(base::BindRepeating(
       &HandleEchoHeader, "/echoheadercache", "max-age=60000"));
   server->RegisterDefaultHandler(PREFIXED_HANDLER("/echo", &HandleEcho));
