@@ -24,10 +24,9 @@ namespace net {
 
 namespace {
 
-std::vector<const http2::adapter::Header> GenerateHeaders(
-    HttpStatusCode status,
-    base::StringPairs headers) {
-  std::vector<const http2::adapter::Header> response_vector;
+std::vector<http2::adapter::Header> GenerateHeaders(HttpStatusCode status,
+                                                    base::StringPairs headers) {
+  std::vector<http2::adapter::Header> response_vector;
   response_vector.emplace_back(
       http2::adapter::HeaderRep(std::string(":status")),
       http2::adapter::HeaderRep(base::NumberToString(status)));
@@ -74,7 +73,7 @@ class Http2Connection::DataFrameSource
     const int64_t result = connection_->OnReadyToSend(concatenated);
     // Write encountered error.
     if (result < 0) {
-      connection_->OnConnectionError();
+      connection_->OnConnectionError(ConnectionError::kSendError);
       return false;
     }
 
@@ -88,7 +87,7 @@ class Http2Connection::DataFrameSource
       // Probably need to handle this better within this test class.
       QUICHE_LOG(DFATAL)
           << "DATA frame not fully flushed. Connection will be corrupt!";
-      connection_->OnConnectionError();
+      connection_->OnConnectionError(ConnectionError::kSendError);
       return false;
     }
 
@@ -148,7 +147,7 @@ class Http2Connection::ResponseDelegate : public HttpResponseDelegate {
     scoped_refptr<HttpResponseHeaders> parsed_headers =
         HttpResponseHeaders::TryToCreate(headers);
     if (parsed_headers->response_code() == 0) {
-      connection_->OnConnectionError();
+      connection_->OnConnectionError(ConnectionError::kParseError);
       LOG(ERROR) << "raw headers could not be parsed";
     }
     base::StringPairs header_pairs;
@@ -436,7 +435,8 @@ int Http2Connection::OnFrameSent(uint8_t frame_type,
   return 0;
 }
 
-bool Http2Connection::OnInvalidFrame(StreamId stream_id, int error_code) {
+bool Http2Connection::OnInvalidFrame(StreamId stream_id,
+                                     InvalidFrameError error) {
   return true;
 }
 
