@@ -10,13 +10,13 @@
 #include <memory>
 #include <string>
 
-#include "base/optional.h"
 #include "net/base/isolation_info.h"
 #include "net/base/net_export.h"
 #include "net/base/privacy_mode.h"
 #include "net/base/request_priority.h"
 #include "net/log/net_log_capture_mode.h"
 #include "net/traffic_annotation/network_traffic_annotation.h"
+#include "third_party/abseil-cpp/absl/types/optional.h"
 
 class GURL;
 
@@ -46,7 +46,7 @@ NET_EXPORT base::Value NetLogURLRequestStartParams(
     PrivacyMode privacy_mode,
     const IsolationInfo& isolation_info,
     const SiteForCookies& site_for_cookies,
-    const base::Optional<url::Origin>& initiator,
+    const absl::optional<url::Origin>& initiator,
     int64_t upload_id);
 
 }  // namespace net
