@@ -228,7 +228,7 @@ void WebSocketMockClientSocketFactoryMaker::AddSSLSocketDataProvider(
 WebSocketTestURLRequestContextHost::WebSocketTestURLRequestContextHost()
     : url_request_context_(true), url_request_context_initialized_(false) {
   url_request_context_.set_client_socket_factory(maker_.factory());
-  auto params = std::make_unique<HttpNetworkSession::Params>();
+  auto params = std::make_unique<HttpNetworkSessionParams>();
   params->enable_spdy_ping_based_connection_checking = false;
   params->enable_quic = false;
   params->enable_websocket_over_http2 = true;
